@@ -925,6 +925,21 @@ void CL_AddPacketEntities (frame_t *frame)
 				CL_LargeHealthParticles(ent.origin);
 		}
 
+		if (!Q_strcasecmp (cl.configstrings[CS_MODELS+(s1->modelindex)], "models/weapons/g_rocket/tris.md2")) {
+			//add clear cover
+			ent.model = R_RegisterModel("models/weapons/g_rocket/cover.md2");
+			ent.flags |= RF_TRANSLUCENT;
+			ent.alpha = 0.30;
+			V_AddEntity (&ent);
+		}	
+		if (!Q_strcasecmp (cl.configstrings[CS_MODELS+(s1->modelindex)], "models/weapons/g_hyperb/tris.md2")) {
+			//add clear cover
+			ent.model = R_RegisterModel("models/weapons/g_hyperb/cover.md2");
+			ent.flags |= RF_TRANSLUCENT;
+			ent.alpha = 0.30;
+			V_AddEntity (&ent);
+		}		
+
 		if (s1->modelindex2)
 		{
 			if (s1->modelindex2 == 255 || (ci->helmet && playermodel))
@@ -1080,7 +1095,7 @@ void CL_AddPacketEntities (frame_t *frame)
 			if (effects & EF_SHIPEXHAUST)
 			{
 				CL_ShipExhaust (cent->lerp_origin, ent.origin, cent);
-				V_AddLight (ent.origin, 200, 1, 1, 0);
+				V_AddLight (ent.origin, 50, 1, 1, 0);
 			}
 			if (effects & EF_ROCKETEXHAUST)
 			{
@@ -1088,7 +1103,7 @@ void CL_AddPacketEntities (frame_t *frame)
 			}
 			else if (effects & EF_HYPERBLASTER)
 			{
-				V_AddLight (ent.origin, 200, 1, 1, 0);
+				V_AddLight (ent.origin, 100, 1, 1, 0);
 			}
 			else if (effects & EF_GIB)
 			{
@@ -1251,7 +1266,7 @@ void CL_AddViewWeapon (player_state_t *ps, player_state_t *ops)
 		gun.flags = oldeffects;
 	}
 
-	//add windows for vehicles
+	//add windows for vehicles, cover for RL
 	if(!(strcmp("vehicles/bomber/v_wep.md2", gun.model->name))) {
 		gun.model = R_RegisterModel("vehicles/bomber/window.md2");
 		gun.flags |= RF_TRANSLUCENT;
@@ -1270,6 +1285,18 @@ void CL_AddViewWeapon (player_state_t *ps, player_state_t *ops)
 		gun.alpha = 0.30;
 		V_AddEntity (&gun);
 	}
+	if(!(strcmp("models/weapons/v_rocket/tris.md2", gun.model->name))) {
+		gun.model = R_RegisterModel("models/weapons/v_rocket/cover.md2");
+		gun.flags |= RF_TRANSLUCENT;
+		gun.alpha = 0.30;
+		V_AddEntity (&gun);
+	}
+	if(!(strcmp("models/weapons/v_hyperb/tris.md2", gun.model->name))) {
+		gun.model = R_RegisterModel("models/weapons/v_hyperb/cover.md2");
+		gun.flags |= RF_TRANSLUCENT;
+		gun.alpha = 0.30;
+		V_AddEntity (&gun);
+	}
 }
 
 
