@@ -429,14 +429,19 @@ void addParticleLight (cparticle_t *p, float light, float lightvel, float lcol0,
 CL_ClearParticles
 ===============
 */
+/*
+Cl_ClearParticle
+*/
+
 void CL_ClearParticles (void)
 {
 	int		i;
 	
+	
 	free_particles = &particles[0];
 	active_particles = NULL;
 
-	for (i=0 ;i<cl_numparticles ; i++)
+	for (i=0 ;i<cl_numparticles ; i++) 
 		particles[i].next = &particles[i+1];
 	particles[cl_numparticles-1].next = NULL;
 }
@@ -897,7 +902,7 @@ void CL_ExplosionParticles (vec3_t org)
 			}
 			if (p && i < 3)
 				addParticleLight (p,
-						p->scale*100*i, 0,
+						p->scale*50*i, 0,
 					.4, .4, 0.1);
 		}
 	}
@@ -1396,51 +1401,6 @@ void CL_BlasterParticles (vec3_t org, vec3_t dir)
 	}
 }
 
-/*
-===============
-CL_BlasterTrail
-
-===============
-*/
-void CL_BlasterTrail (vec3_t start, vec3_t end)
-{
-	vec3_t		move;
-	vec3_t		vec;
-	float		len;
-	int			j;
-	cparticle_t	*p;
-	int			dec;
-
-	VectorCopy (start, move);
-	VectorSubtract (end, start, vec);
-	len = VectorNormalize (vec);
-
-	dec = 5;
-	VectorScale (vec, 5, vec);
-
-	// FIXME: this is a really silly way to have a loop
-	while (len > 0)
-	{
-		len -= dec;
-
-		if (!(p = new_particle()))
-			return;
-
-		VectorClear (p->accel);
-
-		p->alpha = 0.8;
-		p->alphavel = -1.0 / (0.3+frand()*1.2);
-		p->color = 0xe0;
-		for (j=0 ; j<3 ; j++)
-		{
-			p->org[j] = move[j] + crand();
-			p->vel[j] = crand()*5;
-			p->accel[j] = 0;
-		}
-
-		VectorAdd (move, vec, move);
-	}
-}
 /*
 ===============
 CL_BlasterBall
@@ -1678,14 +1638,14 @@ void CL_DiminishingTrail (vec3_t start, vec3_t end, centity_t *old, int flags)
 			}
 			else
 			{
-
+				dec = 10; //less smoke
 				for (j=0 ; j<3 ; j++)
 				{
 					p->org[j] = move[j] + crand()*orgscale;
 					p->vel[j] = crand()*velscale;
 				}
 				
-				p->alphavel = -1.0 / (30+frand()*1.4); //smoke lingers longer
+				p->alphavel = -1.0 / (20+frand()*1.4); //smoke lingers longer
 				p->alpha = .07;
 				p->type = PARTICLE_SMOKE; 
 				p->texnum = r_smoketexture->texnum;
@@ -2072,11 +2032,11 @@ void CL_DisruptorBeam (vec3_t start, vec3_t end)
 
 	MakeNormalVectors (vec, right, up);
 	VectorCopy (vec, vec2);
-	VectorScale (vec, LASERTRAILSPACE, vec);
+	VectorScale (vec, RAILTRAILSPACE, vec);
 	VectorCopy (start, move);
 
 	//muzzleflash	
-	VectorScale (vec2, -LASERTRAILSPACE/2, vec2);
+	VectorScale (vec2, -RAILTRAILSPACE/2, vec2);
 	VectorAdd(start, vec2, start);
 	for(i = 0; i < 3; i++) {
 	
@@ -2091,7 +2051,7 @@ void CL_DisruptorBeam (vec3_t start, vec3_t end)
 		for(j=0; j< 3; j++)
 			p->angle[j] = 0;
 		p->type = PARTICLE_BLASTER;
-		p->scalevel = 2;
+		p->scalevel = 4;
 		p->color = 0xd4;
 		for (j=0 ; j<3 ; j++)
 		{
@@ -2101,44 +2061,11 @@ void CL_DisruptorBeam (vec3_t start, vec3_t end)
 		}
 	}
 	
-	for (; len>0; len -= LASERTRAILSPACE)
+	for (; len>0; len -= RAILTRAILSPACE)
 	{	
 		VectorCopy (move, last);	
 		VectorAdd (move, vec, move);
 	
-		if (!(p = new_particle()))
-				return;
-
-		p->alpha = 1;
-		p->alphavel = -.8 / (0.6+frand()*0.2);
-		p->blenddst = GL_ONE;
-		p->blendsrc = GL_SRC_ALPHA;
-		if(len <= 20) { //end blast 
-			p->texnum = r_flaretexture->texnum;
-			p->scale = 24;
-			for(j=0; j< 3; j++)
-				p->angle[j] = 0;
-			p->type = PARTICLE_BLASTER;
-			p->scalevel = 12;
-		}
-		else {
-			p->texnum = r_beamtexture->texnum;
-			p->scale = 2;
-			VectorCopy(move, p->angle);
-			p->type = PARTICLE_BEAM;
-			p->scalevel = 0;
-		}
-		
-		p->color = 0xd4;
-	
-		for (j=0 ; j<3 ; j++)
-		{
-			p->org[j] = last[j];
-			p->vel[j] = 0;
-			p->accel[j] = 0;
-		}
-		
-		//do the beam again, to make the effect more prominent and bright, and to the end
 		if (!(p = new_particle()))
 				return;
 
@@ -2147,7 +2074,7 @@ void CL_DisruptorBeam (vec3_t start, vec3_t end)
 		p->blenddst = GL_ONE;
 		p->blendsrc = GL_SRC_ALPHA;
 		p->texnum = r_beamtexture->texnum;
-		p->scale = 2;
+		p->scale = 4;
 		VectorCopy(move, p->angle);
 		p->type = PARTICLE_BEAM;
 		p->scalevel = 0;
@@ -2182,11 +2109,11 @@ void CL_LaserBeam (vec3_t start, vec3_t end)
 
 	MakeNormalVectors (vec, right, up);
 	VectorCopy (vec, vec2);
-	VectorScale (vec, LASERTRAILSPACE, vec);
+	VectorScale (vec, RAILTRAILSPACE, vec);
 	VectorCopy (start, move);
 
 	//muzzleflash	
-	VectorScale (vec2, -LASERTRAILSPACE/2, vec2);
+	VectorScale (vec2, -RAILTRAILSPACE/2, vec2);
 	VectorAdd(start, vec2, start);
 	for(i = 0; i < 3; i++) {
 	
@@ -2197,7 +2124,7 @@ void CL_LaserBeam (vec3_t start, vec3_t end)
 		p->blenddst = GL_ONE;
 		p->blendsrc = GL_SRC_ALPHA;
 		p->texnum = r_cflashtexture->texnum;
-		p->scale = 8/(i+1);
+		p->scale = 12/(i+1);
 		for(j=0; j< 3; j++)
 			p->angle[j] = 0;
 		p->type = PARTICLE_BLASTER;
@@ -2211,7 +2138,7 @@ void CL_LaserBeam (vec3_t start, vec3_t end)
 		}
 	}
 	
-	for (; len>0; len -= LASERTRAILSPACE)
+	for (; len>0; len -= RAILTRAILSPACE)
 	{	
 		VectorCopy (move, last);	
 		VectorAdd (move, vec, move);
@@ -2220,7 +2147,7 @@ void CL_LaserBeam (vec3_t start, vec3_t end)
 				return;
 
 		p->alpha = 0.9;
-		p->alphavel = -2.8 / (0.6+frand()*0.2);
+		p->alphavel = -2.8;
 		p->blenddst = GL_ONE;
 		p->blendsrc = GL_SRC_ALPHA;
 		if(len <= 40) { //end blast
@@ -2232,8 +2159,8 @@ void CL_LaserBeam (vec3_t start, vec3_t end)
 			p->scalevel = 12;
 		}
 		else {
-			p->texnum = r_beamtexture->texnum;
-			p->scale = 2;
+			p->texnum = r_beam2texture->texnum;
+			p->scale = 4;
 			VectorCopy(move, p->angle);
 			p->type = PARTICLE_BEAM;
 			p->scalevel = 0;
@@ -2825,7 +2752,92 @@ void CL_TeleportParticles (vec3_t start)
 	}
 }
 
+#define WEATHER_PARTICLES 2048
+static int weather_particles;
+extern unsigned r_weather;  
 
+/*
+Cl_WeatherEffects - adopted from Jay Dolan's Q2W
+*/
+void Cl_WeatherEffects(){
+	int i, j, k;
+	vec3_t start, end;
+	trace_t tr;
+	float ceiling;
+	cparticle_t *p;
+	
+	if(!r_weather)
+		return;
+
+	i = weather_particles;  // we count up from current particles
+	p = NULL;  // so that we add the right amount
+		
+	k = 0;
+	while(i++ < WEATHER_PARTICLES && k++ < 25){
+			
+		VectorCopy(cl.refdef.vieworg, start);
+		start[0] = start[0] + (rand() % 2048) - 1024;
+		start[1] = start[1] + (rand() % 2048) - 1024;
+		
+		VectorCopy(start, end);
+		end[2] += 8192;
+		
+		// trace up looking for sky
+		tr = CM_BoxTrace(start, end, vec3_origin, vec3_origin, 0, MASK_SHOT);
+		
+		if(!(tr.surface->flags & SURF_SKY))
+			continue;
+	
+		// drop down somewhere between sky and player
+		ceiling = tr.endpos[2] > start[2] + 1024 ? start[2] + 1024 : tr.endpos[2];
+		tr.endpos[2] = tr.endpos[2] - ((ceiling - start[2]) * frand());
+		
+		if (!(p = new_particle()))
+			return;	
+		
+		VectorCopy(tr.endpos, p->org);
+		p->org[2] -= 1;
+
+		VectorCopy(start, end);
+		end[2] -= 8192;
+		
+		tr = CM_BoxTrace(p->org, end, vec3_origin, vec3_origin, 0, MASK_ALL);
+		
+		if(!tr.surface)  // this shouldn't happen
+			VectorCopy(start, p->end);
+		else
+			VectorCopy(tr.endpos, p->end);
+		
+		p->type = PARTICLE_WEATHER;
+		// setup the particles
+		if(r_weather == 1){
+			p->texnum = r_raintexture->texnum;
+			p->vel[2] = -800;
+			p->accel[2] = 0;
+			p->alpha = 0.8;
+			p->alphavel = frand() * -1;
+			p->color = 8;
+			p->scale = 6;
+			p->scalevel = 0;
+		}
+		else if(r_weather == 2){
+			p->texnum = r_particletexture->texnum; 
+			p->vel[2] = -120;
+			p->accel[2] = 0;
+			p->alpha = 0.8;
+			p->alphavel = frand() * -1;
+			p->color = 8;
+			p->scale = 1;
+			p->scalevel = 0;
+		}
+		
+		for(j = 0; j < 2; j++){
+			p->vel[j] = crand() * 2;
+			p->accel[j] = crand() * 2;
+		}
+		weather_particles++;
+	}
+}
 /*
 ===============
 CL_AddParticles
@@ -2836,11 +2848,13 @@ void CL_AddParticles (void)
 	cparticle_t		*p, *next;
 	float			alpha, light;
 	float			time, time2;
-	vec3_t			org, angle;
+	vec3_t			org, curorg, angle;
 	cparticle_t		*active, *tail;
 	float			scale;
 	int				i;
 
+	Cl_WeatherEffects();
+
 	active = NULL;
 	tail = NULL;
 
@@ -2855,6 +2869,8 @@ void CL_AddParticles (void)
 			alpha = p->alpha + time*p->alphavel;
 			if (alpha <= 0)
 			{	// faded out
+				if(p->type == PARTICLE_WEATHER)
+					weather_particles--;
 				p->next = free_particles;
 				free_particles = p;
 				continue;
@@ -2874,6 +2890,17 @@ void CL_AddParticles (void)
 		if(scale > 64)
 			scale = 64; //don't want them getting too large.
 
+		// free up weather particles that have hit the ground
+		for(i = 0; i < 3; i++) {
+			curorg[i] = p->org[i] + p->vel[i]*time + p->accel[i]*(time*time);
+		}
+		if(p->type == PARTICLE_WEATHER && (curorg[2] <= p->end[2])){
+			p->next = free_particles;
+			free_particles = p;
+			weather_particles--;
+			continue;
+		}
+	
 		p->next = NULL;
 		if (!tail)
 			active = tail = p;
