@@ -1465,7 +1465,7 @@ redoSkins:;
 					/*FALL THROUGH*/
 
 				case 3: // skin
-					Com_sprintf(fn, sizeof(fn), "players/%s/%s.tga", model, skin);
+					Com_sprintf(fn, sizeof(fn), "players/%s/%s.jpg", model, skin);
 					if (!CL_CheckOrDownloadFile(fn)) {
 						precache_check = CS_PLAYERSKINS + i * PLAYER_MULT + 4;
 						return; // started a download
@@ -1474,7 +1474,7 @@ redoSkins:;
 					/*FALL THROUGH*/
 
 				case 4: // skin_i
-					Com_sprintf(fn, sizeof(fn), "players/%s/%s_i.tga", model, skin);
+					Com_sprintf(fn, sizeof(fn), "players/%s/%s_i.jpg", model, skin);
 					if (!CL_CheckOrDownloadFile(fn)) {
 						precache_check = CS_PLAYERSKINS + i * PLAYER_MULT + 5;
 						return; // started a download
@@ -1574,6 +1574,20 @@ void CL_Precache_f (void)
 	CL_RequestNextDownload();
 }
 
+ #ifdef __unix__
+ void CL_Shell_f (void) {
+	if(Cmd_Argc() < 2) {
+		Com_Printf("Usage: shell command");
+		return;
+	}
+	char line[130];
+	FILE *fp;
+	fp=popen(Cmd_Args(),"r");
+	while (fgets(line, sizeof line, fp))
+	Com_Printf("%s", line);
+	pclose(fp);
+ }
+ #endif
 
 /*
 =================
@@ -1706,6 +1720,10 @@ void CL_InitLocal (void)
 
 	Cmd_AddCommand ("download", CL_Download_f);
 
+	#ifdef __unix__
+	Cmd_AddCommand ("shell", CL_Shell_f);
+	#endif
+
 	//
 	// forward to server commands
 	//
@@ -1739,15 +1757,12 @@ void CL_InitLocal (void)
 	//register all our menu gfx
 	R_RegisterPic("m_main");
 	R_RegisterPic("m_options");
-	R_RegisterPic("m_options_back");
+	R_RegisterPic("menu_back");
 	R_RegisterPic("m_video");
 	R_RegisterPic("m_controls");
-	R_RegisterPic("m_controls_back");
 	R_RegisterPic("m_player");
-	R_RegisterPic("m_player_back");
 	R_RegisterPic("m_bots");
 	R_RegisterPic("m_startserver");
-	R_RegisterPic("m_startserver_back");
 	R_RegisterPic("m_dmoptions");
 	R_RegisterPic("m_mutators");
 	R_RegisterPic("m_single");
@@ -1978,9 +1993,6 @@ void CL_Frame (int msec)
 	}
 }
 
-
-
-
 //============================================================================
 
 /*
