@@ -89,6 +89,7 @@ qboolean	CL_CheckOrDownloadFile (char *filename)
 	char	name[MAX_OSPATH];
 	char	shortname[MAX_OSPATH];
 	qboolean	modelskin = false;
+	qboolean	jpg = false;
 
 	if (strstr (filename, ".."))
 	{
@@ -106,11 +107,33 @@ qboolean	CL_CheckOrDownloadFile (char *filename)
 		sprintf(filename, "%s.tga", shortname);
 	}
 
-
-	if (FS_LoadFile (filename, NULL) != -1)
-	{	// it exists, no need to download
+	//if jpg, be sure to also try tga (player skin situation)
+    if(filename[strlen(filename)-1] == 'g')
+		jpg = true;
+	
+	if (FS_LoadFile (filename, NULL) != -1)	{
+		// it exists, no need to download
 		return true;
 	}
+	else if(modelskin){
+		//try for .jpg
+		COM_StripExtension ( filename, shortname );
+		sprintf(filename, "%s.jpg", shortname);	
+		if (FS_LoadFile (filename, NULL) != -1)	{
+			// it exists, no need to download
+			return true;
+		}
+	}
+	else if(jpg) { //didn't find .jpg skin, try for .tga skin, convoluted, yes indeed.
+		//try for .tga
+		COM_StripExtension ( filename, shortname );
+		sprintf(filename, "%s.tga", shortname);	
+		if (FS_LoadFile (filename, NULL) != -1)	{
+			// it exists, no need to download
+			return true;
+		}
+	}
+
 	strcpy (cls.downloadname, filename);
 
 	// download to a temp name, and only rename
@@ -120,10 +143,9 @@ qboolean	CL_CheckOrDownloadFile (char *filename)
 	strcat (cls.downloadtempname, ".tmp");
 
 	// attempt an http download if available(never try to dl game model skins here)
-	if(!modelskin) {
-		if(cls.downloadurl[0] && CL_HttpDownload())  
+	if(cls.downloadurl[0] && CL_HttpDownload())  
 			return false;
-	}
+	
 
 //ZOID
 	// check to see if we already have a tmp for this file, if so, try to resume
