@@ -41,6 +41,8 @@ typedef struct
 	vec3_t color;
 	int size;
 	int style;
+	float alpha;
+	float time;
 } flare_t;
 
 typedef struct
@@ -98,6 +100,7 @@ typedef struct
 #define PARTICLE_BEAM				23
 #define PARTICLE_DECAL				24
 #define PARTICLE_FLAT				25
+#define PARTICLE_WEATHER			26
 
 #define RDF_BLOOM         4      //BLOOMS
 
