@@ -73,6 +73,9 @@ void ACEAI_Think (edict_t *self)
 {
 	usercmd_t	ucmd;
 
+	if(!game.num_bots)
+		return; //no bots, no need to go here
+
 	// Set up client movement
 	VectorCopy(self->client->ps.viewangles,self->s.angles);
 	VectorSet (self->client->ps.pmove.delta_angles, 0, 0, 0);
@@ -95,7 +98,7 @@ void ACEAI_Think (edict_t *self)
 	if(VectorLength(self->velocity) > 37) 
 		self->suicide_timeout = level.time + 10.0;
 
-	if(self->suicide_timeout < level.time && self->takedamage == DAMAGE_AIM)
+	if(self->suicide_timeout < level.time && self->takedamage == DAMAGE_AIM && !level.intermissiontime)
 	{
 		self->health = 0;
 		player_die (self, self, self, 100000, vec3_origin);
@@ -104,6 +107,10 @@ void ACEAI_Think (edict_t *self)
 	//reset the state from pauses for taunting
 	if(self->suicide_timeout < level.time + 8)
 		self->state = STATE_WANDER;
+
+	//times up on spawn protection 
+	if(level.time > self->client->spawnprotecttime + g_spawnprotect->integer)
+		self->client->spawnprotected = false;
 	
 	// Find any short range goal - but not if in air(ie, jumping a jumppad)
 	if(self->groundentity)
@@ -507,31 +514,18 @@ qboolean ACEAI_CheckShot(edict_t *self)
 }
 
 ///////////////////////////////////////////////////////////////////////
-// Choose the best weapon for bot (simplified)
+// Choose the best weapon for bot 
 ///////////////////////////////////////////////////////////////////////
 void ACEAI_ChooseWeapon(edict_t *self)
 {	
 	float range;
 	vec3_t v;
-	gitem_t *vehicle;
 	
-	vehicle = FindItemByClassname("item_bomber");
-
-	if (self->client->pers.inventory[ITEM_INDEX(vehicle)]) {
-		return; //always use the bombs when in a bomber
+	if (self->in_vehicle) {
+		return; 
 	}
-	vehicle = FindItemByClassname("item_strafer");
-
-	if (self->client->pers.inventory[ITEM_INDEX(vehicle)]) {
-		return; //always use the beams when in a strafer
-	}
-	vehicle = FindItemByClassname("item_hover");
-
-	if (self->client->pers.inventory[ITEM_INDEX(vehicle)]) {
-		return; //always use the beams when in a hovercraft
-	}
-	vehicle = FindItemByClassname("item_deathball");
-	if (self->client->pers.inventory[ITEM_INDEX(vehicle)]) {
+	
+	if (self->in_deathball) {
 		return; //cannot switch or fire weapons when in a deathball.
 	}
 
@@ -612,8 +606,26 @@ void ACEAI_ChooseWeapon(edict_t *self)
 				}
 		}
 	}
+	if(!strcmp(self->faveweap, "Violator"))
+	{
+		if(range < 300) { //because it's a fav weap, we want them to really try and use it
+				if(ACEIT_ChangeWeapon(self,FindItem("Violator")))
+				{
+					self->accuracy = 1.0;
+					return; 
+				}
+		}
+	}
 	//now go through normal weapon favoring routine
-	// always favor the Vaporizer
+	// always favor the Vaporizor, unless close, then use the violator
+	if(range < 200) {
+		if(ACEIT_ChangeWeapon(self,FindItem("Violator")))
+		{
+			self->accuracy = 1.0;
+			return;
+		}
+	}
+
 	if(ACEIT_ChangeWeapon(self,FindItem("Alien Vaporizer")))
 	{
 		self->accuracy = self->weapacc[9];
