@@ -126,11 +126,11 @@ void ACESP_LoadBots(edict_t *ent, int playerleft)
 
 //bots and configurations will be loaded level specific
 	if (((int)(dmflags->value) & DF_SKINTEAMS) || ctf->value || tca->value || cp->value)
-		strcpy(bot_filename, "botinfo/team.tmp");
+		strcpy(bot_filename, BOTDIR"/botinfo/team.tmp");
 	else if(sv_custombots->value)
-		sprintf(bot_filename, "botinfo/custom%i.tmp", sv_custombots->integer);
+		sprintf(bot_filename, BOTDIR"/botinfo/custom%i.tmp", sv_custombots->integer);
 	else
-		sprintf(bot_filename, "botinfo/%s.tmp", level.mapname);
+		sprintf(bot_filename, BOTDIR"/botinfo/%s.tmp", level.mapname);
 
 	if((pIn = fopen(bot_filename, "rb" )) == NULL)
 		return; // bail
@@ -171,7 +171,8 @@ void ACESP_LoadBots(edict_t *ent, int playerleft)
 	}
 	real_players -= playerleft; //done for when this is called as a player is disconnecting
 	
-	
+	if(real_players >= game.maxclients)
+		return; //we have too many slots occupied, so lets not try loading any bots.
 
 	total_players = 0;
 	for(i=0;i<count;i++)
@@ -470,15 +471,6 @@ void ACESP_PutClientInServer (edict_t *bot, qboolean respawn, int team)
 	else 
 		bot->s.modelindex3 = 0;
 
-	if(!strcmp(playermodel, "war")) //special case
-	{
-		bot->s.modelindex4 = gi.modelindex("players/war/weapon.md2");
-		bot->s.modelindex2 = 0;
-	}
-	else if(!strcmp(playermodel, "brainlet"))	
-		bot->s.modelindex4 = gi.modelindex("players/brainlet/gunrack.md2"); //brainlets have a mount
-
-
 	//check for class file
 	bot->ctype = 0;
 	sprintf(modelpath, "players/%s/human", playermodel);
@@ -558,7 +550,7 @@ void ACESP_PutClientInServer (edict_t *bot, qboolean respawn, int team)
 		//if not a respawn, load bot configuration file(specific to each bot)
 		info = Info_ValueForKey (bot->client->pers.userinfo, "name");
  
-		sprintf(bot_configfilename, "botinfo/%s.cfg", info);
+		sprintf(bot_configfilename, BOTDIR"/botinfo/%s.cfg", info);
 		ACECO_ReadConfig(bot_configfilename);
 
 		//set config items
@@ -691,6 +683,8 @@ void ACESP_SetName(edict_t *bot, char *name, char *skin, char *team)
 	else
 		strcpy(bot_name,name);
 
+	bot->dmteam = NO_TEAM; //default
+
 	// skin
 	
 	if (((int)(dmflags->value) & DF_SKINTEAMS) || ctf->value || tca->value || cp->value) //only do this for skin teams, red, blue
@@ -799,12 +793,6 @@ void ACESP_SpawnBot (char *team, char *name, char *skin, char *userinfo)
 	bot->inuse = true;
 	bot->is_bot = true;
 
-	/* Tony: Bots need to know the password for passworded servers
-		otherwise ClientConnect() fails */
-	if (*password->string && strcmp(password->string, "none"))
-		Info_SetValueForKey(userinfo, "password", password->string);
-
-
 	// To allow bots to respawn
 	if(userinfo == NULL)
 		ACESP_SetName(bot, name, skin, team);
