@@ -8,7 +8,7 @@ of the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 See the GNU General Public License for more details.
 
@@ -46,7 +46,7 @@ qboolean CanDamage (edict_t *targ, edict_t *inflictor)
 			return true;
 		return false;
 	}
-	
+
 	trace = gi.trace (inflictor->s.origin, vec3_origin, vec3_origin, targ->s.origin, inflictor, MASK_SOLID);
 	if (trace.fraction == 1.0)
 		return true;
@@ -94,14 +94,14 @@ void Killed (edict_t *targ, edict_t *inflictor, edict_t *attacker, int damage, v
 	if (targ->health < -999)
 		targ->health = -999;
 
-	if (targ->monsterinfo.aiflags & AI_NPC) { //cows never really die, they just return to their 
+	if (targ->monsterinfo.aiflags & AI_NPC) { //cows never really die, they just return to their
 											  //original spawn points
 		//send an effect
 		gi.WriteByte (svc_temp_entity);
 		gi.WriteByte (TE_BFG_BIGEXPLOSION);
 		gi.WritePosition (targ->s.origin);
 		gi.multicast (targ->s.origin, MULTICAST_PHS);
-		
+
 		targ->health = targ->max_health;
 		targ->s.event = EV_PLAYER_TELEPORT;
 		targ->enemy = NULL;
@@ -181,90 +181,6 @@ dflags		these flags are used to control how T_Damage works
 	DAMAGE_NO_PROTECTION	kills godmode, armor, everything
 ============
 */
-static int CheckPowerArmor (edict_t *ent, vec3_t point, vec3_t normal, int damage, int dflags)
-{
-	gclient_t	*client;
-	int			save;
-	int			power_armor_type;
-	int			index;
-	int			damagePerCell;
-	int			pa_te_type;
-	int			power;
-	int			power_used;
-
-	if (!damage)
-		return 0;
-
-	client = ent->client;
-
-	if (dflags & DAMAGE_NO_ARMOR)
-		return 0;
-
-	if (client)
-	{
-		power_armor_type = PowerArmorType (ent);
-		if (power_armor_type != POWER_ARMOR_NONE)
-		{
-			index = ITEM_INDEX(FindItem("Cells"));
-			power = client->pers.inventory[index];
-		}
-	}
-	else if (ent->svflags & SVF_MONSTER)
-	{
-		power_armor_type = ent->monsterinfo.power_armor_type;
-		power = ent->monsterinfo.power_armor_power;
-	}
-	else
-		return 0;
-
-	if (power_armor_type == POWER_ARMOR_NONE)
-		return 0;
-	if (!power)
-		return 0;
-
-	if (power_armor_type == POWER_ARMOR_SCREEN)
-	{
-		vec3_t		vec;
-		float		dot;
-		vec3_t		forward;
-
-		// only works if damage point is in front
-		AngleVectors (ent->s.angles, forward, NULL, NULL);
-		VectorSubtract (point, ent->s.origin, vec);
-		VectorNormalize (vec);
-		dot = DotProduct (vec, forward);
-		if (dot <= 0.3)
-			return 0;
-
-		damagePerCell = 1;
-		pa_te_type = TE_SCREEN_SPARKS;
-		damage = damage / 3;
-	}
-	else
-	{
-		damagePerCell = 2;
-		pa_te_type = TE_SHIELD_SPARKS;
-		damage = (2 * damage) / 3;
-	}
-
-	save = power * damagePerCell;
-	if (!save)
-		return 0;
-	if (save > damage)
-		save = damage;
-
-	SpawnDamage (pa_te_type, point, normal, save);
-	ent->powerarmor_time = level.time + 0.2;
-
-	power_used = save / damagePerCell;
-
-	if (client)
-		client->pers.inventory[index] -= power_used;
-	else
-		ent->monsterinfo.power_armor_power -= power_used;
-	return save;
-}
-
 static int CheckArmor (edict_t *ent, vec3_t point, vec3_t normal, int damage, int te_sparks, int dflags)
 {
 	gclient_t	*client;
@@ -318,18 +234,22 @@ void T_Damage (edict_t *targ, edict_t *inflictor, edict_t *attacker, vec3_t dir,
 	int			take;
 	int			save;
 	int			asave;
-	int			psave;
 	int			te_sparks;
 
 	if (!targ->takedamage)
 		return;
 
+	if(mod != MOD_TELEFRAG)
+		if(targ->inuse && targ->client)
+			if(targ->client->spawnprotected)
+				return;
+			
 	// friendly fire avoidance
 	// if enabled you can't hurt teammates (but you can hurt yourself)
 	// knockback still occurs
-	if ((targ != attacker) && ((deathmatch->value && ((int)(dmflags->value) & (DF_MODELTEAMS | DF_SKINTEAMS))) || ctf->value || tca->value || cp->value))
+	if ((targ != attacker) && ((deathmatch->value && ((int)(dmflags->value) & (DF_SKINTEAMS))) || ctf->value || tca->value || cp->value))
 	{
-		if (OnSameTeam (targ, attacker))
+		if (OnSameTeam (targ, attacker) && mod != MOD_TELEFRAG) //telefrag kills no matter what
 		{
 			if ((int)(dmflags->value) & DF_NO_FRIENDLY_FIRE)
 				damage = 0;
@@ -340,6 +260,11 @@ void T_Damage (edict_t *targ, edict_t *inflictor, edict_t *attacker, vec3_t dir,
 			safe_centerprintf(attacker, "Stop shooting your teammates!!!");
 		}
 	}
+
+	if (targ == attacker) {
+		damage *= wep_selfdmgmulti->value;
+	}
+
 	meansOfDeath = mod;
 
 	// easy mode takes half damage
@@ -385,7 +310,7 @@ void T_Damage (edict_t *targ, edict_t *inflictor, edict_t *attacker, vec3_t dir,
 	}
 	//diminish plasma splash, as we want this to be minimal, as it's more used for tricks
 	if(mod == MOD_PLASMA_SPLASH)
-		damage = 1;
+		damage /= (1+ (int)(random() * 10.0));
 
 	take = damage;
 	save = 0;
@@ -410,9 +335,6 @@ void T_Damage (edict_t *targ, edict_t *inflictor, edict_t *attacker, vec3_t dir,
 		save = damage;
 	}
 
-	psave = CheckPowerArmor (targ, point, normal, take, dflags);
-	take -= psave;
-
 	asave = CheckArmor (targ, point, normal, take, te_sparks, dflags);
 	take -= asave;
 
@@ -435,11 +357,16 @@ void T_Damage (edict_t *targ, edict_t *inflictor, edict_t *attacker, vec3_t dir,
 			else
 				SpawnDamage (TE_BLOOD, point, normal, take);
 		}
-		else
+		else {
 			SpawnDamage (te_sparks, point, normal, take);
+			if(tca->value) {
+				if(!(strcmp(targ->classname, "misc_redspidernode")) || !(strcmp(targ->classname, "misc_bluespidernode")))
+					safe_centerprintf(attacker, "Spider health at %i percent", 100*targ->health/600);
+			}
+		}
 
 		targ->health = targ->health - take;
-			
+
 		if (targ->health <= 0)
 		{
 			if (client)
@@ -465,7 +392,6 @@ void T_Damage (edict_t *targ, edict_t *inflictor, edict_t *attacker, vec3_t dir,
 	// at the end of the frame
 	if (client)
 	{
-		client->damage_parmor += psave;
 		client->damage_armor += asave;
 		client->damage_blood += take;
 		client->damage_knockback += knockback;
