@@ -751,12 +751,12 @@ void T_RadiusDamage (edict_t *inflictor, edict_t *attacker, float damage, edict_
 #define DAMAGE_NO_PROTECTION	0x00000020  // armor, shields, invulnerability, and godmode have no effect
 
 #define DEFAULT_BULLET_HSPREAD	300
-#define DEFAULT_BULLET_VSPREAD	500
+#define DEFAULT_BULLET_VSPREAD	300
 #define DEFAULT_SHOTGUN_HSPREAD	1000
 #define DEFAULT_SHOTGUN_VSPREAD	500
 #define DEFAULT_DEATHMATCH_SHOTGUN_COUNT	12
 #define DEFAULT_SHOTGUN_COUNT	12
-#define DEFAULT_SSHOTGUN_COUNT	20
+#define DEFAULT_SSHOTGUN_COUNT	15
 
 //
 // g_monster.c
@@ -1142,6 +1142,12 @@ struct gclient_s
 	//joust attempts - for limiting how many times you can joust at a time
 	int joustattempts;
 
+	//movetime - used for special moves
+	float lastmovetime;
+	int lastsidemove;
+	int dodge;
+	int moved;
+
 	float spawnprotecttime;
 	qboolean spawnprotected;
 
@@ -1362,6 +1368,13 @@ struct edict_s
 	//class(human = 0; alien = 1; robot = 2;)
 	int ctype;
 
+	//model specific gibs
+	int usegibs;
+	char head[64];
+	char leg[64];
+	char arm[64];
+	char body[64];
+
 };
 
 void FL_think (edict_t *self);
