@@ -8,7 +8,7 @@ of the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 See the GNU General Public License for more details.
 
@@ -30,6 +30,7 @@ int	sm_meat_index;
 int	snd_fry;
 int meansOfDeath;
 int bot_won;
+qboolean stayed;
 
 edict_t		*g_edicts;
 
@@ -47,6 +48,25 @@ cvar_t  *excessive;
 cvar_t  *grapple;
 cvar_t  *classbased;
 
+//duel mode
+cvar_t	*g_duel;
+
+cvar_t	*g_losehealth;
+cvar_t	*g_losehealth_num;
+
+//weapons
+cvar_t	*wep_selfdmgmulti;
+
+//health/max health/max ammo
+cvar_t	*g_spawnhealth;
+cvar_t	*g_maxhealth;
+cvar_t	*g_maxbullets;
+cvar_t	*g_maxshells;
+cvar_t	*g_maxrockets;
+cvar_t	*g_maxgrenades;
+cvar_t	*g_maxcells;
+cvar_t	*g_maxslugs;
+
 //quick weapon change
 cvar_t  *quickweap;
 
@@ -54,9 +74,15 @@ cvar_t  *quickweap;
 cvar_t  *anticamp;
 cvar_t  *camptime;
 
+//random quad
+cvar_t  *g_randomquad;
+
 //warmup
 cvar_t  *warmuptime;
 
+//spawn protection
+cvar_t  *g_spawnprotect;
+
 //joust mode
 cvar_t  *joustmode;
 
@@ -111,10 +137,6 @@ void ClientDisconnect (edict_t *ent);
 void ClientBegin (edict_t *ent);
 void ClientCommand (edict_t *ent);
 void RunEntity (edict_t *ent);
-void WriteGame (char *filename, qboolean autosave);
-void ReadGame (char *filename);
-void WriteLevel (char *filename);
-void ReadLevel (char *filename);
 void InitGame (void);
 void G_RunFrame (void);
 
@@ -148,11 +170,6 @@ game_export_t *GetGameAPI (game_import_t *import)
 	globals.Shutdown = ShutdownGame;
 	globals.SpawnEntities = SpawnEntities;
 
-	globals.WriteGame = WriteGame;
-	globals.ReadGame = ReadGame;
-	globals.WriteLevel = WriteLevel;
-	globals.ReadLevel = ReadLevel;
-
 	globals.ClientThink = ClientThink;
 	globals.ClientConnect = ClientConnect;
 	globals.ClientUserinfoChanged = ClientUserinfoChanged;
@@ -199,7 +216,7 @@ void Com_Printf (char *msg, ...)
 
 //======================================================================
 
-//#ifdef __linux__
+//#ifdef __unix__
 
 #define Z_MAGIC		0x1d1d
 
@@ -230,14 +247,14 @@ Z_Free
 ========================
 */
 void Z_Free (void *ptr)
-{       
+{
 	zhead_t *z;
 
 	z = ((zhead_t *)ptr) - 1;
 
 	if (z->magic != Z_MAGIC)
 		Sys_Error (ERR_FATAL, "Z_Free: bad magic");
- 
+
 	z->prev->next = z->next;
 	z->next->prev = z->prev;
 
@@ -361,7 +378,7 @@ void EndDMLevel (void)
 		free(s);
 	}
 
-	if((int)(ctf->value)) { //wasn't in the dedicated list 
+	if((int)(ctf->value)) { //wasn't in the dedicated list
 		BeginIntermission (CreateTargetChangeLevel (level.mapname));
 		return;
 	}
@@ -447,8 +464,8 @@ void EndDMLevel (void)
 			else if(mapnames[0][0]) //no more maps, repeat list
 				BeginIntermission (CreateTargetChangeLevel (mapnames[0]) );
 		}
-	}			
-	
+	}
+
 	if (level.nextmap[0]) // go to a specific map
 		BeginIntermission (CreateTargetChangeLevel (level.nextmap) );
 	else {	// search for a changelevel
@@ -475,7 +492,7 @@ void CheckNeedPass (void)
 
 	// if password or spectator_password has changed, update needpass
 	// as needed
-	if (password->modified || spectator_password->modified) 
+	if (password->modified || spectator_password->modified)
 	{
 		password->modified = spectator_password->modified = false;
 
@@ -499,6 +516,7 @@ void ResetLevel (void) //for resetting players and items after warmup
 	int i;
 	edict_t	*ent;
 	gitem_t *item;
+
 	for (i=0 ; i<maxclients->value ; i++)
 	{
 		ent = g_edicts + i + 1;
@@ -532,14 +550,14 @@ void ResetLevel (void) //for resetting players and items after warmup
 		{
 			if (!item->classname)
 				continue;
-		
+
 			if (!strcmp(item->classname, ent->classname))
 			{	// found it
 				DoRespawn(ent);
 				break;
 			}
 		}
-		
+
 	}
 	return;
 }
@@ -557,7 +575,7 @@ void CheckDMRules (void)
 	edict_t		*cl_ent;
 
 	if(!tca->value && !ctf->value && !cp->value && !((int)(dmflags->value) & DF_SKINTEAMS)) {
-		if(level.time <= warmuptime->value) { 
+		if(level.time <= warmuptime->value) {
 				if((warmuptime->value - level.time ) == 3) {
 					for (i=0 ; i<maxclients->value ; i++)
 					{
@@ -585,7 +603,7 @@ void CheckDMRules (void)
 						gi.sound (cl_ent, CHAN_AUTO, gi.soundindex("misc/one.wav"), 1, ATTN_STATIC, 0);
 					}
 				}
-				if(level.time == warmuptime->value) { 
+				if(level.time == warmuptime->value) {
 					for (i=0 ; i<maxclients->value ; i++)
 					{
 					cl_ent = g_edicts + 1 + i;
@@ -612,7 +630,7 @@ void CheckDMRules (void)
 							safe_centerprintf(cl_ent, "%i...\n", int_time);
 					}
 				}
-		}			
+		}
 	}
 
 	if (level.intermissiontime)
@@ -630,10 +648,10 @@ void CheckDMRules (void)
 			return;
 		}
 	}
-	
+
 	if (fraglimit->value && ((tca->value || ctf->value || cp->value || ((int)(dmflags->value) & DF_SKINTEAMS)) || level.time > warmuptime->value))
 	{
-		
+
 		//team scores
 		if (((int)(dmflags->value) & DF_SKINTEAMS) || ctf->value || cp->value) //it's all about the team!
 		{
@@ -654,7 +672,7 @@ void CheckDMRules (void)
 
 				EndDMLevel();
 				return;
-			}			
+			}
 		}
 		else {
 			top_score = 0;
@@ -737,7 +755,7 @@ void CheckDMRules (void)
 	}
 	if(tca->value) {
 		if(blue_team_score == 0) {
-				
+
 			safe_bprintf(PRINT_HIGH, "Red Team wins!\n");
 
 			bot_won = 0; //we don't care if it's a bot that wins
@@ -746,18 +764,17 @@ void CheckDMRules (void)
 			return;
 		}
 		if(red_team_score == 0) {
-			
+
 			safe_bprintf(PRINT_HIGH, "Blue Team wins!\n");
 
 			bot_won = 0; //we don't care if it's a bot that wins
 
 			EndDMLevel();
 			return;
-		}		
+		}
 	}
 }
 
-
 /*
 =============
 ExitLevel
@@ -765,12 +782,18 @@ ExitLevel
 */
 void ExitLevel (void)
 {
-	int		i;
-	edict_t	*ent;
-	char	command [256];
+	int			i;
+	edict_t		*ent;
+	char		command [256];
+	qboolean	stayed = false;
+
+	if(strcmp(level.mapname, level.changemap) || timelimit->value) {
+		Com_sprintf (command, sizeof(command), "map \"%s\"\n", level.changemap);
+		gi.AddCommandString (command);
+	}
+	else 
+		stayed = true; //no need to reload map if staying on same level!
 
-	Com_sprintf (command, sizeof(command), "gamemap \"%s\"\n", level.changemap);
-	gi.AddCommandString (command);
 	level.changemap = NULL;
 	level.exitintermission = 0;
 	level.intermissiontime = 0;
@@ -785,6 +808,42 @@ void ExitLevel (void)
 			continue;
 		if (ent->health > ent->client->pers.max_health)
 			ent->health = ent->client->pers.max_health;
+		
+		if(stayed) {
+			ent->client->resp.score = 0;
+			ent->client->resp.deaths = 0;
+			if(!ent->is_bot) { //players
+				ent->takedamage = DAMAGE_AIM;
+				ent->solid = SOLID_BBOX;
+				ent->deadflag = DEAD_NO;	
+				PutClientInServer (ent);
+			}
+			else { //reset various bot junk
+				ent->takedamage = DAMAGE_AIM;
+				ent->solid = SOLID_BBOX;
+				ent->deadflag = DEAD_NO;
+				ACESP_PutClientInServer (ent,true,0);
+			}
+			if(g_duel->value) {
+				ClientPlaceInQueue(ent);
+				ClientCheckQueue(ent);	
+			}
+		}
+	}
+	if(stayed) {
+		for (i=1, ent=g_edicts+i ; i < globals.num_edicts ; i++,ent++) {
+
+			if (!ent->inuse)
+				continue;
+			if(ent->client) {//not players
+				continue;
+			}
+			//remove podiums
+			if(!strcmp(ent->classname, "pad"))
+				G_FreeEdict(ent);
+			if(tca->value)
+				ent->powered = true;
+		}
 	}
 	if(tca->value) {
 		blue_team_score = 4;
@@ -797,6 +856,8 @@ void ExitLevel (void)
 	blue_team_cnt = 0;
 	red_team_cnt = 0; //reset everything now that we are done
 	print1 = print2 = print3 = false;
+	if(!stayed)
+		game.num_bots = 0; //do this *just* incase something got whacked or isn't getting set.
 }
 
 /*
@@ -853,7 +914,7 @@ void G_RunFrame (void)
 		{
 			ClientBeginServerFrame (ent);
 // ACEBOT_ADD
-		
+
 // ACEBOT_END
 		}
 
