@@ -142,7 +142,7 @@ void ThrowGib (edict_t *self, char *gibname, int damage, int type, int effects)
 
 	gib = G_Spawn();
 
-	VectorScale (self->size, 0.5, size);
+	VectorScale (self->size, 1, size);
 	VectorAdd (self->absmin, size, origin);
 	gib->s.origin[0] = origin[0] + crandom() * size[0];
 	gib->s.origin[1] = origin[1] + crandom() * size[1];
@@ -159,7 +159,7 @@ void ThrowGib (edict_t *self, char *gibname, int damage, int type, int effects)
 	{
 		gib->movetype = MOVETYPE_BOUNCE;
 		gib->touch = gib_touch;
-		vscale = 0.5;
+		vscale = 0.2;
 	}
 	else
 	{
@@ -185,17 +185,9 @@ void ThrowClientHead (edict_t *self, int damage)
 	vec3_t	vd;
 	char	*gibname;
 
-	if (rand()&1)
-	{
-		gibname = "models/objects/gibs/sm_meat/tris.md2";
-		self->s.skinnum = 0;		// second skin is player
-	}
-	else
-	{
-		gibname = "models/objects/gibs/sm_meat/tris.md2";
+	gibname = "models/objects/gibs/sm_meat/tris.md2";
 		self->s.skinnum = 0;
-	}
-
+	
 	self->s.origin[2] += 32;
 	self->s.frame = 0;
 	gi.setmodel (self, gibname);
@@ -986,7 +978,7 @@ void SP_misc_teleporter (edict_t *ent)
 		return;
 	}
 
-	gi.setmodel (ent, "models/objects/dmspot/tris.md2");
+	gi.setmodel (ent, "models/objects/blank/tris.md2");
 	ent->s.skinnum = 1;
 	ent->s.effects = EF_TELEPORTER;
 	ent->solid = SOLID_BBOX;
@@ -1491,3 +1483,12 @@ void SP_misc_bluespidernode (edict_t *ent)
 	M_droptofloor (ent);
 }
 
+void SP_misc_mapmodel (edict_t *ent) //random .md2 map models
+{
+	gi.setmodel (ent, ent->model);
+
+	ent->solid = SOLID_NOT; //will need clipping brushes around it
+
+	gi.linkentity (ent);
+	
+}
\ No newline at end of file
