@@ -93,6 +93,7 @@ void SP_misc_rednode (edict_t *self);
 void SP_misc_bluenode (edict_t *self);
 void SP_misc_bluespidernode (edict_t *self);
 void SP_misc_redspidernode (edict_t *self);
+void SP_misc_mapmodel (edict_t *self);
 
 spawn_t	spawns[] = {
 	{"item_health", SP_item_health},
@@ -181,6 +182,7 @@ spawn_t	spawns[] = {
 	{"misc_bluenode", SP_misc_bluenode},
 	{"misc_redspidernode", SP_misc_redspidernode},
 	{"misc_bluespidernode", SP_misc_bluespidernode},
+	{"misc_mapmodel", SP_misc_mapmodel},
 	{NULL, NULL}
 };
 
@@ -835,16 +837,16 @@ void SP_worldspawn (edict_t *ent)
 
 	//precache all base player models.  this eliminates the "stutter" when a player joins the game
 	gi.modelindex ("players/martianenforcer/tris.md2");
-	gi.modelindex ("players/martian/tris.md2");
+//	gi.modelindex ("players/martian/tris.md2");
 	gi.modelindex ("players/martiancyborg/tris.md2");
 	gi.modelindex ("players/enforcer/tris.md2");
-	gi.modelindex ("players/infantry/tris.md2");
-	gi.modelindex ("players/war/tris.md2");
-	gi.modelindex ("players/brainlet/tris.md2");
-	gi.modelindex ("players/robot/tris.md2");
-	gi.modelindex ("players/construct/tris.md2");
+//	gi.modelindex ("players/infantry/tris.md2");
+//	gi.modelindex ("players/war/tris.md2");
+//	gi.modelindex ("players/brainlet/tris.md2");
+//	gi.modelindex ("players/robot/tris.md2");
+//	gi.modelindex ("players/construct/tris.md2");
 	gi.modelindex ("players/lauren/tris.md2");
-	gi.modelindex ("players/rustbot/tris.md2");
+//	gi.modelindex ("players/rustbot/tris.md2");
 
 	//do the w_weps
 	// THIS ORDER MUST MATCH THE DEFINES IN g_local.h
