@@ -321,7 +321,7 @@ void use_target_steam (edict_t *self, edict_t *other, edict_t *activator)
 	gi.WritePosition (self->s.origin);
 	gi.WriteDir (self->movedir);
 	gi.WriteByte (self->sounds);
-	gi.multicast (self->s.origin, MULTICAST_PVS);
+	gi.multicast (self->s.origin, MULTICAST_PHS);
 
 }
 
@@ -337,7 +337,6 @@ void SP_target_steam (edict_t *self)
 }
 void use_target_fire (edict_t *self, edict_t *other, edict_t *activator)
 {
-	vec3_t start;
 
 	gi.WriteByte (svc_temp_entity);
 	gi.WriteByte (TE_FIRE);
@@ -345,18 +344,7 @@ void use_target_fire (edict_t *self, edict_t *other, edict_t *activator)
 	gi.WritePosition (self->s.origin);
 	gi.WriteDir (self->movedir);
 	gi.WriteByte (self->sounds);
-	gi.multicast (self->s.origin, MULTICAST_PVS);
-
-	VectorCopy(self->s.origin, start);
-	start[2] = start[2] + 100;
-
-	gi.WriteByte (svc_temp_entity);
-	gi.WriteByte (TE_SMOKE);
-	gi.WriteByte (self->count);
-	gi.WritePosition (start);
-	gi.WriteDir (self->movedir);
-	gi.WriteByte (self->sounds);
-	gi.multicast (start, MULTICAST_PVS);
+	gi.multicast (self->s.origin, MULTICAST_PHS);
 }
 
 void SP_target_fire (edict_t *self)
@@ -538,9 +526,9 @@ void target_laser_think (edict_t *self)
 		if (self->spawnflags & 8)
 			gi.WriteByte (TE_LIGHTNING);
 		else if (self->spawnflags & 16)
-			gi.WriteByte (TE_HEATBEAM);
+			gi.WriteByte (TE_VAPORBEAM);
 		else
-			gi.WriteByte (TE_SHOTGUN);
+			gi.WriteByte (TE_LASERBEAM);
 		gi.WritePosition (start);
 		gi.WritePosition (end);
 		gi.multicast (start, MULTICAST_PHS); 
