@@ -660,6 +660,7 @@ void player_die (edict_t *self, edict_t *inflictor, edict_t *attacker, int damag
 	char	*info;
 	int	got_vehicle = 0;
 	int	number_of_gibs = 0;
+	int	gib_effect = EF_GREENGIB;
 
 	if (self->in_vehicle) {
 		Reset_player(self);	//get the player out of the vehicle
@@ -734,8 +735,7 @@ void player_die (edict_t *self, edict_t *inflictor, edict_t *attacker, int damag
 	{	// gib
 		self->takedamage	= DAMAGE_NO;
 		self->s.modelindex3	= 0;    //remove helmet, if a martian
-		self->s.modelindex4	= 0;    //war machine rider
-
+	
 		gi.WriteByte (svc_temp_entity);
 		gi.WriteByte (TE_DEATHFIELD);
 		gi.WritePosition (self->s.origin);
@@ -758,10 +758,13 @@ void player_die (edict_t *self, edict_t *inflictor, edict_t *attacker, int damag
 
 		if(self->ctype == 0) { //alien
 
-			for (n= 0; n < number_of_gibs; n++)
-				ThrowGib (self, "models/objects/gibs/mart_gut/tris.md2", damage, GIB_ORGANIC, EF_GREENGIB);
+			for (n= 0; n < number_of_gibs; n++) {
+				ThrowGib (self, "models/objects/gibs/mart_gut/tris.md2", damage, GIB_METALLIC, EF_GREENGIB);
+				ThrowGib (self, "models/objects/debris2/tris.md2", damage, GIB_METALLIC, 0);
+			}
 		}
 		else if(self->ctype == 2) { //robot
+			gib_effect = 0;
 			for (n= 0; n < number_of_gibs; n++) {
 				ThrowGib (self, "models/objects/debris3/tris.md2", damage, GIB_METALLIC, 0);
 				ThrowGib (self, "models/objects/debris1/tris.md2", damage, GIB_METALLIC, 0);
@@ -773,10 +776,24 @@ void player_die (edict_t *self, edict_t *inflictor, edict_t *attacker, int damag
 			gi.multicast (self->s.origin, MULTICAST_PHS);
 		}
 		else { //human
+			gib_effect = EF_GIB;
 			for (n= 0; n < number_of_gibs; n++)
-				ThrowGib (self, "models/objects/gibs/sm_meat/tris.md2", damage, GIB_ORGANIC, EF_GIB);
+				ThrowGib (self, "models/objects/gibs/sm_meat/tris.md2", damage, GIB_METALLIC, EF_GIB);
 		}
 
+		//don't use until 6.11 is released, so we don't have lots of people with 
+		//triangles everywhere.  We could precache all this stuff tho and put the models
+		//on icculus perhaps, but we are having problems with the udp downloading of models.
+		//So, better safe than sorry and don't precache.
+		//So in other words, the flag files just won't be uploaded to SVN until release time.
+		if(self->usegibs) {
+			ThrowGib (self, self->head, damage, GIB_ORGANIC, gib_effect);
+			ThrowGib (self, self->leg, damage, GIB_ORGANIC, gib_effect);
+			ThrowGib (self, self->leg, damage, GIB_ORGANIC, gib_effect);
+			ThrowGib (self, self->body, damage, GIB_ORGANIC, gib_effect);
+			ThrowGib (self, self->arm, damage, GIB_ORGANIC, gib_effect);
+			ThrowGib (self, self->arm, damage, GIB_ORGANIC, gib_effect);
+		}
 	}
 	else
 	{	// normal death
@@ -1075,12 +1092,18 @@ edict_t *SelectRandomCTFSpawnPoint (void)
 	int		count = 0;
 	int		selection;
 	float	range, range1, range2;
+	char	whichteam[16];
 
 	spot = NULL;
 	range1 = range2 = 99999;
 	spot1 = spot2 = NULL;
 
-	while ((spot = G_Find (spot, FOFS(classname), "info_player_red")) != NULL)
+	if(random() < 0.5)
+		strcpy(whichteam, "info_player_red");
+	else
+		strcpy(whichteam, "info_player_blue");
+
+	while ((spot = G_Find (spot, FOFS(classname), whichteam)) != NULL)
 	{
 		count++;
 		range = PlayersRangeFromSpot(spot);
@@ -1118,7 +1141,7 @@ edict_t *SelectRandomCTFSpawnPoint (void)
 	spot = NULL;
 	do
 	{
-		spot = G_Find (spot, FOFS(classname), "info_player_red");
+		spot = G_Find (spot, FOFS(classname), whichteam);
 		if (spot == spot1 || spot == spot2)
 			selection++;
 	} while(selection--);
@@ -1300,7 +1323,8 @@ void InitBodyQue (void)
 
 void body_die (edict_t *self, edict_t *inflictor, edict_t *attacker, int damage, vec3_t point)
 {
-	int	n;
+	int	n;	
+	int gib_effect = EF_GREENGIB;
 	self->s.modelindex3 = 0;    //remove helmet, if a martian
 	self->s.modelindex4 = 0;
 	if (self->health < -40)
@@ -1308,9 +1332,10 @@ void body_die (edict_t *self, edict_t *inflictor, edict_t *attacker, int damage,
 		if(self->ctype == 0) { //alien
 
 			for (n= 0; n < 4; n++)
-				ThrowGib (self, "models/objects/gibs/mart_gut/tris.md2", damage, GIB_ORGANIC, EF_GREENGIB);
+				ThrowGib (self, "models/objects/gibs/mart_gut/tris.md2", damage, GIB_METALLIC, EF_GREENGIB);
 		}
 		else if(self->ctype == 2) { //robot
+			gib_effect = 0;
 			for (n= 0; n < 4; n++)
 				ThrowGib (self, "models/objects/debris3/tris.md2", damage, GIB_METALLIC, 0);
 			for (n= 0; n < 4; n++)
@@ -1323,9 +1348,20 @@ void body_die (edict_t *self, edict_t *inflictor, edict_t *attacker, int damage,
 
 		}
 		else { //human
+			gib_effect = EF_GIB;
 			for (n= 0; n < 4; n++)
-				ThrowGib (self, "models/objects/gibs/sm_meat/tris.md2", damage, GIB_ORGANIC, EF_GIB);
+				ThrowGib (self, "models/objects/gibs/sm_meat/tris.md2", damage, GIB_METALLIC, EF_GIB);
 		}
+
+		if(self->usegibs) {
+			ThrowGib (self, self->head, damage, GIB_ORGANIC, gib_effect);
+			ThrowGib (self, self->leg, damage, GIB_ORGANIC, gib_effect);
+			ThrowGib (self, self->leg, damage, GIB_ORGANIC, gib_effect);
+			ThrowGib (self, self->body, damage, GIB_ORGANIC, gib_effect);
+			ThrowGib (self, self->arm, damage, GIB_ORGANIC, gib_effect);
+			ThrowGib (self, self->arm, damage, GIB_ORGANIC, gib_effect);
+		}
+
 		self->s.origin[2] -= 48;
 		ThrowClientHead (self, damage);
 		self->takedamage = DAMAGE_NO;
@@ -1382,11 +1418,18 @@ void CopyToBodyQue (edict_t *ent)
 	body->die = body_die;
 	body->takedamage = DAMAGE_YES;
 	body->ctype = ent->ctype;
-
+	body->usegibs = ent->usegibs;
 	body->timestamp = level.time;
 	body->nextthink = level.time + 5;
 	body->think = BodySink;
 
+	if(body->usegibs) {
+		strcpy(body->arm, ent->arm);
+		strcpy(body->leg, ent->leg);
+		strcpy(body->head, ent->head);
+		strcpy(body->body, ent->body);
+	}
+
 	gi.linkentity (body);
 }
 
@@ -1670,14 +1713,7 @@ void PutClientInServer (edict_t *ent)
 		ent->s.modelindex3 = 0;
 
 	ent->s.modelindex4 = 0;
-	if(!strcmp(playermodel, "war")) //special case
-	{
-		ent->s.modelindex4 = gi.modelindex("players/war/weapon.md2");
-		ent->s.modelindex2 = 0;
-	}
-	else if(!strcmp(playermodel, "brainlet"))
-		ent->s.modelindex4 = gi.modelindex("players/brainlet/gunrack.md2"); //brainlets have a mount
-
+	
 	//check for class file
 	ent->ctype = 0; //alien is default
 	sprintf(modelpath, "players/%s/human", playermodel);
@@ -1857,8 +1893,7 @@ void ClientBeginDeathmatch (edict_t *ent)
 
 	InitClientResp (ent->client);
 
-	if(((int)(dmflags->value) & DF_SKINTEAMS) || ctf->value || tca->value || cp->value)
-		ent->dmteam = NO_TEAM;
+	ent->dmteam = NO_TEAM;
 
 	// locate ent at a spawn point
 	if(!ent->client->pers.spectator) //fixes invisible player bugs caused by leftover svf_noclients
@@ -2030,8 +2065,8 @@ void ClientUserinfoChanged (edict_t *ent, char *userinfo, int whereFrom)
 	// set skin
 	s = Info_ValueForKey (userinfo, "skin");
 
-	//do the team skin check, only forcibly set teams for bots
-	if(ent->is_bot) {
+	//do the team skin check
+	if(true) {
 		if (((int)(dmflags->value) & DF_SKINTEAMS) || ctf->value || tca->value || cp->value) //only do this for skin teams, red, blue
 		{
 			copychar = false;
@@ -2055,7 +2090,7 @@ void ClientUserinfoChanged (edict_t *ent, char *userinfo, int whereFrom)
 			}
 			playermodel[j] = 0;
 
-			if((!strcmp(playerskin, "red"))	|| (!strcmp(playerskin, "blue"))) //was valid teamskin
+			if(ent->is_bot && ((!strcmp(playerskin, "red"))	|| (!strcmp(playerskin, "blue")))) //was valid teamskin
 			{
 				if(!strcmp(playerskin, "red"))
 				{
@@ -2127,14 +2162,21 @@ void ClientUserinfoChanged (edict_t *ent, char *userinfo, int whereFrom)
 		ent->s.modelindex3 = 0;
 
 	ent->s.modelindex4 = 0;
-	if(!strcmp(playermodel, "war")) //special case, presents a problem for CTF.  Grr.
-	{
-		ent->s.modelindex4 = gi.modelindex("players/war/weapon.md2");
-		ent->s.modelindex2 = 0;
-	}
-	else if(!strcmp(playermodel, "brainlet"))
-		ent->s.modelindex4 = gi.modelindex("players/brainlet/gunrack.md2"); //brainlets have a mount
 
+	//do gib checking here
+	//check for gib file
+	ent->usegibs = 0; //alien is default
+	sprintf(modelpath, "players/%s/usegibs", playermodel);
+	Q2_FindFile (modelpath, &file);
+	if(file) { //use model specific gibs
+		ent->usegibs = 1;
+		sprintf(ent->head, "players/%s/head.md2", playermodel);
+		sprintf(ent->body, "players/%s/body.md2", playermodel);
+		sprintf(ent->leg, "players/%s/leg.md2", playermodel);
+		sprintf(ent->arm, "players/%s/arm.md2", playermodel);
+		fclose(file);
+	}
+	
 	// fov
 	if (deathmatch->value && ((int)dmflags->value & DF_FIXED_FOV))
 	{
@@ -2465,6 +2507,7 @@ void ClientThink (edict_t *ent, usercmd_t *ucmd)
 	int		i, j;
 	pmove_t	pm;
 	qboolean sproing, haste;
+	vec3_t addspeed, forward, up;
 
 	level.current_entity = ent;
 	client = ent->client;
@@ -2527,10 +2570,30 @@ void ClientThink (edict_t *ent, usercmd_t *ucmd)
 		if (memcmp(&client->old_pmove, &pm.s, sizeof(pm.s)))
 		{
 			pm.snapinitial = true;
-	//		gi.dprintf ("pmove changed!\n");
 		}
 
 		ucmd->forwardmove *= 1.3;
+	
+		//dodging 
+		client->dodge = false;
+		if(ent->groundentity && ucmd->forwardmove == 0 && ucmd->sidemove != 0 && client->moved == false && ((level.time - client->lastmovetime) < .15))
+		{
+			if((ucmd->sidemove < 0 && client->lastsidemove < 0) || (ucmd->sidemove > 0 && client->lastsidemove > 0)) {
+				if(ucmd->sidemove > 0)
+					client->dodge = 1;
+				else
+					client->dodge = -1;
+				ucmd->upmove += 100;
+			}
+		}
+
+		if(ucmd->sidemove != 0 || ucmd->forwardmove != 0) {
+			client->lastmovetime = level.time;
+			client->lastsidemove = ucmd->sidemove;
+			client->moved = true;
+		}
+		else //we had a frame with no movement
+			client->moved = false;
 
 		pm.cmd = *ucmd;
 
@@ -2553,7 +2616,7 @@ void ClientThink (edict_t *ent, usercmd_t *ucmd)
 
 		// perform a pmove
 		gi.Pmove (&pm);
-
+		
 		// save results of pmove
 		client->ps.pmove = pm.s;
 		client->old_pmove = pm.s;
@@ -2566,6 +2629,23 @@ void ClientThink (edict_t *ent, usercmd_t *ucmd)
 				ent->velocity[i] = pm.s.velocity[i]*0.125;
 		}
 
+		//check for a dodge, and peform if true
+		if(client->dodge != 0) {
+			AngleVectors (ent->s.angles, forward, addspeed, up);
+			addspeed[0] *= 300*client->dodge;
+			addspeed[1] *= 300*client->dodge;
+			//limit to reasonable
+			for(i = 0; i < 2; i++) {
+				if(addspeed[i] > 800)
+					addspeed[i] = 800;
+				if(addspeed[i] < -800)
+					addspeed[i] = -800;
+			}
+			VectorAdd(ent->velocity, addspeed, ent->velocity);
+			client->dodge = false;
+			client->lastmovetime = level.time;
+		}
+
 		VectorCopy (pm.mins, ent->mins);
 		VectorCopy (pm.maxs, ent->maxs);
 
