@@ -683,8 +683,8 @@ void weapon_plasma_fire (edict_t *ent)
 
 	if (is_quad)
 	{
-		damage *= 4;
-		kick *= 4;
+		damage *= 2;
+		kick *= 2;
 	}
 
 	//alt fire
@@ -751,8 +751,8 @@ void weapon_energy_field_fire (edict_t *ent)
 
 	if (is_quad)
 	{
-		radius_damage *=4;
-		damage *= 4;
+		radius_damage *=2; 
+		damage *= 2;
 		kick *= 4;
 	}
 
@@ -893,8 +893,8 @@ void weapon_flamethrower_fire (edict_t *ent)
 
 	PlayerNoise(ent, start, PNOISE_WEAPON);
 
-	if (is_quad)
-		damage *= 4;
+	if (is_quad) 
+		damage *= 2;
 
 	AngleVectors (ent->client->v_angle, forward, right, NULL);
 
@@ -944,8 +944,8 @@ void Weapon_RocketLauncher_Fire (edict_t *ent)
 	damage_radius = 120;
 	if (is_quad)
 	{
-		damage *= 4;
-		radius_damage *= 4;
+		damage *= 2; 
+		radius_damage *= 2;
 	}
 
 	AngleVectors (ent->client->v_angle, forward, right, NULL);
@@ -1007,7 +1007,7 @@ void Blaster_Fire (edict_t *ent, vec3_t g_offset, int damage, qboolean hyper, in
 	vec3_t	offset;
 
 	if (is_quad)
-		damage *= 4;
+		damage *= 2; 
 
 	AngleVectors (ent->client->v_angle, forward, right, NULL);
 
@@ -1030,7 +1030,7 @@ void Blaster_Fire (edict_t *ent, vec3_t g_offset, int damage, qboolean hyper, in
 			ent->altfire = !ent->altfire;
 			if(ent->altfire) {
 				gi.sound(ent, CHAN_AUTO, gi.soundindex("weapons/blastf1a.wav"), 1, ATTN_NORM, 0);
-				fire_blasterball (ent, start, forward, damage*2, 1000, effect, hyper);
+				fire_blasterball (ent, start, forward, damage*3, 1000, effect, hyper);
 			}
 		}
 		else {
@@ -1106,8 +1106,8 @@ void Weapon_Bomber_Fire (edict_t *ent)
 	damage_radius = 250;
 	if (is_quad)
 	{
-		damage *= 4;
-		radius_damage *= 4;
+		damage *= 2; 
+		radius_damage *= 2;
 	}
 
 	AngleVectors (ent->client->v_angle, forward, right, NULL);
@@ -1159,7 +1159,7 @@ void Weapon_Strafer_Fire (edict_t *ent)
 		damage = 20;
 
 	if (is_quad)
-		damage *= 4;
+		damage *= 2; 
 
 	AngleVectors (ent->client->v_angle, forward, right, NULL);
 
@@ -1243,7 +1243,7 @@ void Weapon_Hover_Fire (edict_t *ent)
 		damage = 20;
 
 	if (is_quad)
-		damage *= 4;
+		damage *= 2; 
 
 	AngleVectors (ent->client->v_angle, forward, right, NULL);
 
@@ -1285,7 +1285,6 @@ void Weapon_Hover (edict_t *ent) //for now
 }
 void Weapon_Beamgun_Fire (edict_t *ent)
 {
-	//float	rotation; rem out unneed variable
 	vec3_t	offset;
 	int		effect;
 	int		damage;
@@ -1315,14 +1314,12 @@ void Weapon_Beamgun_Fire (edict_t *ent)
 				effect = EF_HYPERBLASTER;
 			else
 				effect = 0;
-			if (deathmatch->value) {
-				if(excessive->value)
-					damage = 45;
-				else
-					damage = 15;
-			}
+		
+			if(excessive->value)
+				damage = 25;
 			else
-				damage = 20;
+				damage = 10; 
+					
 			Blaster_Fire (ent, offset, damage, true, effect);
 			if (! ( (int)dmflags->value & DF_INFINITE_AMMO ) )
 				ent->client->pers.inventory[ent->client->ammo_index]--;
@@ -1360,14 +1357,10 @@ void Machinegun_Fire (edict_t *ent)
 	int			damage;
 	int			kick = 2;
 
-	if (deathmatch->value) {
-		if(excessive->value)
-			damage = 60;
-		else
-			damage = 20;
-	}
+	if(excessive->value)
+		damage = 60;
 	else
-		damage = 20;
+		damage = 18;
 
 	if ((ent->client->ps.gunframe == 5) && !(ent->client->buttons & BUTTON_ATTACK || ent->client->buttons & BUTTON_ATTACK2))
 	{
@@ -1422,13 +1415,21 @@ void Machinegun_Fire (edict_t *ent)
 
 	if (is_quad)
 	{
-		damage *= 4;
-		kick *= 4;
+		damage *= 2; 
+		kick *= 2;
 	}
 
 	AngleVectors (ent->client->v_angle, forward, right, NULL);//was up
-	VectorScale (forward, -16 * random(), ent->client->kick_origin);
-	ent->client->kick_angles[0] = -6 * random();
+	if(ent->client->ps.gunframe == 6 || ent->client->ps.gunframe == 8 || ent->client->ps.gunframe == 10 || ent->client->ps.gunframe == 12)
+	{	
+		if(ent->altfire)
+			ent->client->kick_angles[0] = -3; /* Kick view up */
+		else
+		{
+			ent->client->kick_angles[2] = (random() - 0.5)*3; /* Twist the view around a bit */
+			ent->client->kick_angles[0] = -1; /* tiny kick for pulsing effect */
+		}
+	}
 
 	if(ent->client->ps.gunframe == 6 && ent->client->buttons & BUTTON_ATTACK2) {
 		int bullet_count = DEFAULT_SSHOTGUN_COUNT;
@@ -1526,8 +1527,8 @@ void weapon_floater_fire (edict_t *ent)
 	damage_radius = 120;
 	if (is_quad || excessive->value)
 	{
-		damage *= 4;
-		radius_damage *= 4;
+		damage *= 2; 
+		radius_damage *= 2;
 	}
 
 	AngleVectors (ent->client->v_angle, forward, right, NULL);
@@ -1687,9 +1688,9 @@ void Violator_Fire (edict_t *ent)
 	else
 		ent->client->ps.gunframe++;
 
-	if (is_quad) {
-		damage *= 4;
-		kick *=4;
+	if (is_quad) { 
+		damage *= 2;
+		kick *=2;
 	}
 
 	AngleVectors (ent->client->v_angle, forward, right, NULL);
@@ -1704,10 +1705,10 @@ void Violator_Fire (edict_t *ent)
 	
 		VectorSet(offset, 1, 1, ent->viewheight-0.5);
 		P_ProjectSource (ent->client, ent->s.origin, offset, forward, right, start);
-		fire_violator(ent, start, forward, damage*2, kick, 1);
-		fire_violator(ent, start, right, damage*2, kick, 1);
-		fire_violator(ent, start, left, damage*2, kick, 1);
-		fire_violator(ent, start, back, damage*2, kick, 1);
+		fire_violator(ent, start, forward, damage/2, kick*20, 1);
+		fire_violator(ent, start, right, damage/2, kick*20, 1);
+		fire_violator(ent, start, left, damage/2, kick*20, 1);
+		fire_violator(ent, start, back, damage/2, kick*20, 1);
 
 		ent->client->resp.weapon_shots[8]++;
 
