@@ -8,7 +8,7 @@ of the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 See the GNU General Public License for more details.
 
@@ -90,7 +90,7 @@ Adds command text at the end of the buffer
 void Cbuf_AddText (char *text)
 {
 	int		l;
-	
+
 	l = strlen (text);
 
 	if (cmd_text.cursize + l >= cmd_text.maxsize)
@@ -126,10 +126,10 @@ void Cbuf_InsertText (char *text)
 	}
 	else
 		temp = NULL;	// shut up compiler
-		
+
 // add the entire text of the file
 	Cbuf_AddText (text);
-	
+
 // add the copied off data
 	if (templen)
 	{
@@ -223,7 +223,7 @@ void Cbuf_Execute (void)
 
 		memcpy (line, text, i);
 		line[i] = 0;
-		
+
 // delete the text from the command buffer and move remaining commands down
 // this is necessary because commands (exec, alias) can insert data at the
 // beginning of the text buffer
@@ -239,7 +239,7 @@ void Cbuf_Execute (void)
 
 // execute the command line
 		Cmd_ExecuteString (line);
-		
+
 		if (cmd_wait)
 		{
 			// skip out while text still remains in buffer, leaving it
@@ -314,7 +314,7 @@ qboolean Cbuf_AddLateCommands (void)
 	}
 	if (!s)
 		return false;
-		
+
 	text = Z_Malloc (s+1);
 	text[0] = 0;
 	for (i=1 ; i<argc ; i++)
@@ -323,11 +323,11 @@ qboolean Cbuf_AddLateCommands (void)
 		if (i != argc-1)
 			strcat (text, " ");
 	}
-	
+
 // pull out the commands
 	build = Z_Malloc (s+1);
 	build[0] = 0;
-	
+
 	for (i=0 ; i<s-1 ; i++)
 	{
 		if (text[i] == '+')
@@ -339,7 +339,7 @@ qboolean Cbuf_AddLateCommands (void)
 
 			c = text[j];
 			text[j] = 0;
-			
+
 			strcat (build, text+i);
 			strcat (build, "\n");
 			text[j] = c;
@@ -350,7 +350,7 @@ qboolean Cbuf_AddLateCommands (void)
 	ret = (build[0] != 0);
 	if (ret)
 		Cbuf_AddText (build);
-	
+
 	Z_Free (text);
 	Z_Free (build);
 
@@ -390,7 +390,7 @@ void Cmd_Exec_f (void)
 		return;
 	}
 	Com_Printf ("execing %s\n",Cmd_Argv(1));
-	
+
 	// the file doesn't have a trailing 0, so we need to copy it off
 	f2 = Z_Malloc(len+1);
 	memcpy (f2, f, len);
@@ -413,7 +413,7 @@ Just prints the rest of the line to the console
 void Cmd_Echo_f (void)
 {
 	int		i;
-	
+
 	for (i=1 ; i<Cmd_Argc() ; i++)
 		Com_Printf ("%s ",Cmd_Argv(i));
 	Com_Printf ("\n");
@@ -464,7 +464,7 @@ void Cmd_Alias_f (void)
 		a->next = cmd_alias;
 		cmd_alias = a;
 	}
-	strcpy (a->name, s);	
+	strcpy (a->name, s);
 
 // copy the rest of the command line
 	cmd[0] = 0;		// start out with a null string
@@ -476,7 +476,7 @@ void Cmd_Alias_f (void)
 			strcat (cmd, " ");
 	}
 	strcat (cmd, "\n");
-	
+
 	a->value = CopyString (cmd);
 }
 
@@ -522,7 +522,7 @@ char	*Cmd_Argv (int arg)
 {
 	if ( (unsigned)arg >= cmd_argc )
 		return cmd_null_string;
-	return cmd_argv[arg];	
+	return cmd_argv[arg];
 }
 
 /*
@@ -577,7 +577,7 @@ char *Cmd_MacroExpandString (char *text)
 		token = COM_Parse (&start);
 		if (!start)
 			continue;
-	
+
 		token = Cvar_VariableString (token);
 
 		j = strlen(token);
@@ -629,10 +629,10 @@ void Cmd_TokenizeString (char *text, qboolean macroExpand)
 // clear the args from the last string
 	for (i=0 ; i<cmd_argc ; i++)
 		Z_Free (cmd_argv[i]);
-		
+
 	cmd_argc = 0;
 	cmd_args[0] = 0;
-	
+
 	// macro expand the text
 	if (macroExpand)
 		text = Cmd_MacroExpandString (text);
@@ -646,7 +646,7 @@ void Cmd_TokenizeString (char *text, qboolean macroExpand)
 		{
 			text++;
 		}
-		
+
 		if (*text == '\n')
 		{	// a newline seperates commands in the buffer
 			text++;
@@ -672,7 +672,7 @@ void Cmd_TokenizeString (char *text, qboolean macroExpand)
 				else
 					break;
 		}
-			
+
 		com_token = COM_Parse (&text);
 		if (!text)
 			return;
@@ -684,7 +684,7 @@ void Cmd_TokenizeString (char *text, qboolean macroExpand)
 			cmd_argc++;
 		}
 	}
-	
+
 }
 
 
@@ -696,14 +696,14 @@ Cmd_AddCommand
 void	Cmd_AddCommand (char *cmd_name, xcommand_t function)
 {
 	cmd_function_t	*cmd;
-	
+
 // fail if the command is a variable name
 	if (Cvar_VariableString(cmd_name)[0])
 	{
 		Com_Printf ("Cmd_AddCommand: %s already defined as a var\n", cmd_name);
 		return;
 	}
-	
+
 // fail if the command already exists
 	for (cmd=cmd_functions ; cmd ; cmd=cmd->next)
 	{
@@ -774,36 +774,99 @@ qboolean	Cmd_Exists (char *cmd_name)
 Cmd_CompleteCommand
 ============
 */
+char	retval[256];
 char *Cmd_CompleteCommand (char *partial)
 {
-	cmd_function_t	*cmd;
-	int				len;
-	cmdalias_t		*a;
-	
+	cmd_function_t *cmd;
+	int             len, i, o, p;
+	cmdalias_t     *a;
+	cvar_t         *cvar;
+	char           *pmatch[1024];
+	qboolean        diff = false;
+
 	len = strlen(partial);
-	
+
 	if (!len)
 		return NULL;
-		
-// check for exact match
-	for (cmd=cmd_functions ; cmd ; cmd=cmd->next)
-		if (!strcmp (partial,cmd->name))
-			return cmd->name;
-	for (a=cmd_alias ; a ; a=a->next)
-		if (!strcmp (partial, a->name))
-			return a->name;
 
-// check for partial match
-	for (cmd=cmd_functions ; cmd ; cmd=cmd->next)
-		if (!strncmp (partial,cmd->name, len))
+        /* check for exact match */
+	for (cmd = cmd_functions; cmd; cmd = cmd->next)
+		if (!strcmp(partial, cmd->name))
 			return cmd->name;
-	for (a=cmd_alias ; a ; a=a->next)
-		if (!strncmp (partial, a->name, len))
+	for (a = cmd_alias; a; a = a->next)
+		if (!strcmp(partial, a->name))
 			return a->name;
+	for (cvar = cvar_vars; cvar; cvar = cvar->next)
+		if (!strcmp(partial, cvar->name))
+			return cvar->name;
 
+	for (i = 0; i < 1024; i++)
+		pmatch[i] = NULL;
+	i = 0;
+
+	/* check for partial match */
+	for (cmd = cmd_functions; cmd; cmd = cmd->next)
+		if (!strncmp(partial, cmd->name, len)) {
+			pmatch[i] = cmd->name;
+			i++;
+		}
+	for (a = cmd_alias; a; a = a->next)
+		if (!strncmp(partial, a->name, len)) {
+			pmatch[i] = a->name;
+			i++;
+		}
+	for (cvar = cvar_vars; cvar; cvar = cvar->next)
+		if (!strncmp(partial, cvar->name, len)) {
+			pmatch[i] = cvar->name;
+			i++;
+		}
+	if (i) {
+		if (i == 1)
+			return pmatch[0];
+
+		Com_Printf("\nListing matches for '%s'...\n", partial);
+		for (o = 0; o < i; o++)
+			Com_Printf("  %s\n", pmatch[o]);
+
+ 		strcpy(retval, "");
+		p = 0;
+		while (!diff && p < 256) {
+			retval[p] = pmatch[0][p];
+			for (o = 0; o < i; o++) {
+				if (p > strlen(pmatch[o]))
+					continue;
+				if (retval[p] != pmatch[o][p]) {
+					retval[p] = 0;
+					diff = true;
+				}
+			}
+			p++;
+		}
+		Com_Printf("Found %i matches\n", i);
+		return retval;
+	}
 	return NULL;
 }
 
+qboolean Cmd_IsComplete(char *command)
+{
+	cmd_function_t *cmd;
+	cmdalias_t     *a;
+	cvar_t         *cvar;
+
+	/* check for exact match */
+	for (cmd = cmd_functions; cmd; cmd = cmd->next)
+		if (!strcmp(command, cmd->name))
+			return true;
+	for (a = cmd_alias; a; a = a->next)
+		if (!strcmp(command, a->name))
+			return true;
+	for (cvar = cvar_vars; cvar; cvar = cvar->next)
+		if (!strcmp(command, cvar->name))
+			return true;
+
+	return false;
+}
 
 /*
 ============
@@ -814,12 +877,12 @@ FIXME: lookupnoadd the token to speed search?
 ============
 */
 void	Cmd_ExecuteString (char *text)
-{	
+{
 	cmd_function_t	*cmd;
 	cmdalias_t		*a;
 
 	Cmd_TokenizeString (text, true);
-			
+
 	// execute the command line
 	if (!Cmd_Argc())
 		return;		// no tokens
@@ -853,7 +916,7 @@ void	Cmd_ExecuteString (char *text)
 			return;
 		}
 	}
-	
+
 	// check cvars
 	if (Cvar_Command ())
 		return;
