@@ -537,6 +537,22 @@ pack_t *FS_LoadPackFile (char *packfile)
 	return pack;
 }
 
+/*
+ * ========= FS_FileExists ========
+ */
+qboolean
+FS_FileExists(char *path)
+{
+	FILE*	f;
+
+	FS_FOpenFile(path, &f);
+
+	if (f != 0) {
+		FS_FCloseFile(f);
+		return (true);
+	}
+	return (false);
+}
 
 /*
 ================
@@ -734,6 +750,12 @@ void FS_SetGamedir (char *dir)
 	else
 	{
 		Cvar_FullSet ("gamedir", dir, CVAR_SERVERINFO|CVAR_NOSET);
+#ifdef DATADIR
+		FS_AddGameDirectory (va("%s/%s", DATADIR, dir) );
+#endif
+#ifdef LIBDIR
+		FS_AddGameDirectory (va("%s/%s", LIBDIR, dir) );
+#endif
 		FS_AddGameDirectory (va("%s/%s", fs_basedir->string, dir) );
 #ifdef __unix__
 		FS_AddHomeAsGameDirectory(dir);
@@ -790,6 +812,9 @@ void FS_Link_f (void)
 
 /*
 ** FS_ListFiles
+**
+** IMPORTANT: does not count the guard in returned "numfiles" anymore, to
+** avoid adding/subtracting 1 all the time.
 */
 char **FS_ListFiles( char *findname, int *numfiles, unsigned musthave, unsigned canthave )
 {
@@ -809,8 +834,8 @@ char **FS_ListFiles( char *findname, int *numfiles, unsigned musthave, unsigned
 	if ( !nfiles )
 		return NULL;
 
-	nfiles++; // add space for a guard
 	*numfiles = nfiles;
+	nfiles++; // add space for a guard
 
 	list = malloc( sizeof( char * ) * nfiles );
 	memset( list, 0, sizeof( char * ) * nfiles );
@@ -834,23 +859,177 @@ char **FS_ListFiles( char *findname, int *numfiles, unsigned musthave, unsigned
 	return list;
 }
 
-//#ifdef __unix__
 void FS_FreeFileList (char **list, int n) // jit
 {
 	int i;
 
 	for (i = 0; i < n; i++)
 	{
-		if (list[i])
-		{
-			free(list[i]);
-			list[i] = 0;
-		}
+		free(list[i]);
+		list[i] = 0;
 	}
 
 	free(list);
 }
-//#endif
+
+/*
+ * CompareAttributesPack
+ *
+ * Compare file attributes (musthave and canthave) in packed files. If
+ * "output" is not NULL, "size" is greater than zero and the file matches the
+ * attributes then a copy of the matching string will be placed there (with
+ * SFF_SUBDIR it changes).
+ *
+ * Returns a boolean value, true if the attributes match the file.
+ */
+qboolean
+ComparePackFiles(const char *findname, const char *name,
+    unsigned musthave, unsigned canthave, char *output, int size)
+{
+	qboolean	 retval;
+	char		*ptr;
+	char		 buffer[MAX_OSPATH];
+
+	strncpy(buffer, name, sizeof(buffer)-1);
+	buffer[sizeof(buffer)-1] = '\0';
+
+	if ((canthave & SFF_SUBDIR) && name[strlen(name)-1] == '/')
+		return (false);
+
+	if (musthave & SFF_SUBDIR) {
+		if ((ptr = strrchr(buffer, '/')) != NULL)
+			*ptr = '\0';
+		else
+			return (false);
+	}
+
+	if ((musthave & SFF_HIDDEN) || (canthave & SFF_HIDDEN)) {
+		if ((ptr = strrchr(buffer, '/')) == NULL)
+			ptr = buffer;
+		if (((musthave & SFF_HIDDEN) && ptr[1] != '.') ||
+		    ((canthave & SFF_HIDDEN) && ptr[1] == '.'))
+			return (false);
+	}
+
+	if (canthave & SFF_RDONLY)
+		return (false);
+
+	retval = glob_match((char *)findname, buffer);
+
+	if (retval && output != NULL) {
+		strncpy(output, buffer, size-1);
+		buffer[size-1] = '\0';
+	}
+
+	return (retval);
+}
+
+/*
+ * FS_ListFilesInFS
+ *
+ * Create a list of files that match a criteria.
+ *
+ * Searchs are relative to the game directory and use all the search paths
+ * including .pak and .pk3 files.
+ */
+char **
+FS_ListFilesInFS(char *findname, int *numfiles, unsigned musthave,
+    unsigned canthave)
+{
+	searchpath_t	*search;		/* Search path. */
+	int		i, j;			/* Loop counters. */
+	int		nfiles;			/* Number of files found. */
+	int		tmpnfiles;		/* Temp number of files. */
+	char		**tmplist;		/* Temporary list of files. */
+	char		**list;			/* List of files found. */
+	char		path[MAX_OSPATH];	/* Temporary path. */
+
+	nfiles = 0;
+	list = malloc(sizeof(char *));
+
+	for (search = fs_searchpaths; search != NULL; search = search->next) {
+		if (search->pack != NULL) {
+			if (canthave & SFF_INPACK)
+				continue;
+
+			for (i = 0, j = 0; i < search->pack->numfiles; i++)
+				if (ComparePackFiles(findname,
+				    search->pack->files[i].name,
+				    musthave, canthave, NULL, 0))
+					j++;
+			if (j == 0)
+				continue;
+			nfiles += j;
+			list = realloc(list, nfiles * sizeof(char *));
+			for (i = 0, j = nfiles - j;
+			    i < search->pack->numfiles;
+			    i++)
+				if (ComparePackFiles(findname,
+				    search->pack->files[i].name,
+				    musthave, canthave, path, sizeof(path)))
+					list[j++] = strdup(path);
+		} else if (search->filename != NULL) {
+			if (musthave & SFF_INPACK)
+				continue;
+
+			Com_sprintf(path, sizeof(path), "%s/%s",
+			    search->filename, findname);
+			tmplist = FS_ListFiles(path, &tmpnfiles, musthave,
+			    canthave);
+			if (tmplist != NULL) {
+				nfiles += tmpnfiles;
+				list = realloc(list, nfiles * sizeof(char *));
+				for (i = 0, j = nfiles - tmpnfiles;
+				    i < tmpnfiles;
+				    i++, j++)
+					list[j] = strdup(tmplist[i] +
+					    strlen(search->filename) + 1);
+				FS_FreeFileList(tmplist, tmpnfiles);
+			}
+		}
+	}
+
+	/* Delete duplicates. */
+	tmpnfiles = 0;
+	for (i = 0; i < nfiles; i++) {
+		if (list[i] == NULL)
+			continue;
+		for (j = i + 1; j < nfiles; j++)
+			if (list[j] != NULL &&
+			    strcmp(list[i], list[j]) == 0) {
+				free(list[j]);
+				list[j] = NULL;
+				tmpnfiles++;
+			}
+	}
+
+	if (tmpnfiles > 0) {
+		nfiles -= tmpnfiles;
+		tmplist = malloc(nfiles * sizeof(char *));
+		for (i = 0, j = 0; i < nfiles + tmpnfiles; i++)
+			if (list[i] != NULL)
+				tmplist[j++] = list[i];
+		free(list);
+		list = tmplist;
+	}
+
+	/* Add a guard. */
+	if (nfiles > 0) {
+		nfiles++;
+		list = realloc(list, nfiles * sizeof(char *));
+		list[nfiles - 1] = NULL;
+	} else {
+		free(list);
+		list = NULL;
+	}
+
+	/* IMPORTANT: Don't count the guard when returning nfiles. */
+	nfiles--;
+
+	*numfiles = nfiles;
+
+	return (list);
+}
 
 /*
 ** FS_Dir_f
@@ -887,7 +1066,7 @@ void FS_Dir_f( void )
 		{
 			int i;
 
-			for ( i = 0; i < ndirs-1; i++ )
+			for ( i = 0; i < ndirs; i++ )
 			{
 				if ( strrchr( dirnames[i], '/' ) )
 					Com_Printf( "%s\n", strrchr( dirnames[i], '/' ) + 1 );
@@ -977,6 +1156,19 @@ void FS_InitFilesystem (void)
 	Cmd_AddCommand ("link", FS_Link_f);
 	Cmd_AddCommand ("dir", FS_Dir_f );
 
+	//
+	// DATADIR / LIBDIR support.
+	// Both directories are used to load data and libraries from, allowing
+	// different OSes to have them where they want, according to their
+	// conventions.
+	//
+#ifdef DATADIR
+	FS_AddGameDirectory (va("%s/"BASEDIRNAME, DATADIR));
+#endif
+#ifdef LIBDIR
+	FS_AddGameDirectory (va("%s/"BASEDIRNAME, LIBDIR));
+#endif
+
 	//
 	// basedir <path>
 	// allows the game to run from outside the data tree
@@ -1001,6 +1193,3 @@ void FS_InitFilesystem (void)
 	else
 		FS_SetGamedir ("arena");
 }
-
-
-
