@@ -23,7 +23,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "../game/q_shared.h"
 
 
-#define	VERSION		6.1
+#define	VERSION		7.0
 
 #define	BASEDIRNAME	"data1"
 
@@ -544,8 +544,8 @@ NET
 
 #define	PORT_ANY	-1
 
-#define	MAX_MSGLEN		2800//1400		// max length of a message
-#define	PACKET_HEADER	20//10			// two ints and a short
+#define	MAX_MSGLEN		2800		// max length of a message
+#define	PACKET_HEADER	20			// two ints and a short
 
 typedef enum {NA_LOOPBACK, NA_BROADCAST, NA_IP, NA_IPX, NA_BROADCAST_IPX} netadrtype_t;
 
@@ -732,13 +732,17 @@ int		FS_LoadFileZ (const char *path, void **buffer); // jit - null-terminated
 void	FS_Read (void *buffer, int len, FILE *f);
 // properly handles partial reads
 
-#ifdef __unix__
-void	FS_FreeFileList (char **list, int n);
-#endif
 void	FS_FreeFile (void *buffer);
 
 void	FS_CreatePath (char *path);
 
+qboolean FS_FileExists(char *path);
+
+#define SFF_INPACK	0x20	/* For FS_ListFilesInFS(). */
+
+char	**FS_ListFiles(char *findname, int *numfiles, unsigned musthave, unsigned canthave);
+char	**FS_ListFilesInFS(char *findname, int *numfiles, unsigned musthave, unsigned canthave);
+void	FS_FreeFileList (char **list, int n);
 
 /*
 ==============================================================
