@@ -247,8 +247,8 @@ void R_InitBloomTextures( void )
 	r_bloom_diamond_size = Cvar_Get( "r_bloom_diamond_size", "8", CVAR_ARCHIVE );
 	r_bloom_intensity = Cvar_Get( "r_bloom_intensity", "0.5", CVAR_ARCHIVE );
 	r_bloom_darken = Cvar_Get( "r_bloom_darken", "8", CVAR_ARCHIVE );
-	r_bloom_sample_size = Cvar_Get( "r_bloom_sample_size", "128", CVAR_ARCHIVE|CVAR_LATCH );
-	r_bloom_fast_sample = Cvar_Get( "r_bloom_fast_sample", "0", CVAR_ARCHIVE|CVAR_LATCH );
+	r_bloom_sample_size = Cvar_Get( "r_bloom_sample_size", "128", CVAR_ARCHIVE );
+	r_bloom_fast_sample = Cvar_Get( "r_bloom_fast_sample", "0", CVAR_ARCHIVE );
 
 	BLOOM_SIZE = 0;
 	if( !r_bloom->integer )
@@ -586,5 +586,11 @@ void R_BloomBlend ( refdef_t *fd )
 		1.0 );
 
 	R_Bloom_DrawEffect();
+
+	qglColor3f (1,1,1);   
+    qglDisable (GL_BLEND);   
+    qglEnable (GL_TEXTURE_2D);   
+    qglBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);   
+    qglDepthMask (1);    
 }
 
