@@ -19,6 +19,12 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 #include "r_local.h"
+#ifdef _WIN32
+#include "jpeg/jpeglib.h"
+#endif
+#ifndef _WIN32
+#include <jpeglib.h>
+#endif
 #include <GL/glu.h>
 
 image_t		gltextures[MAX_GLTEXTURES];
@@ -36,8 +42,8 @@ extern cvar_t	*cl_hudimage2;
 unsigned	d_8to24table[256];
 
 qboolean GL_Upload8 (byte *data, int width, int height,  qboolean mipmap, qboolean is_sky );
-qboolean GL_Upload32 (unsigned *data, int width, int height,  qboolean mipmap);
-qboolean GL_Upload32_hires (unsigned *data, int width, int height,  qboolean mipmap);
+qboolean GL_Upload32 (unsigned *data, int width, int height,  qboolean mipmap, qboolean is_normalmap);
+qboolean GL_Upload32_hires (unsigned *data, int width, int height,  qboolean mipmap, qboolean is_normalmap);
 
 int		gl_solid_format = 3;
 int		gl_alpha_format = 4;
@@ -554,6 +560,153 @@ void LoadPCX (char *filename, byte **pic, byte **palette, int *width, int *heigh
 
 	FS_FreeFile (pcx);
 }
+/*
+=================================================================
+
+JPEG LOADING
+
+By Robert 'Heffo' Heffernan
+
+=================================================================
+*/
+
+void jpg_null(j_decompress_ptr cinfo)
+{
+}
+
+unsigned char jpg_fill_input_buffer(j_decompress_ptr cinfo)
+{
+    Com_Printf("Premature end of JPEG data\n");
+    return 1;
+}
+
+void jpg_skip_input_data(j_decompress_ptr cinfo, long num_bytes)
+{
+        
+    cinfo->src->next_input_byte += (size_t) num_bytes;
+    cinfo->src->bytes_in_buffer -= (size_t) num_bytes;
+
+    if (cinfo->src->bytes_in_buffer < 0) 
+		Com_Printf("Premature end of JPEG data\n");
+}
+
+void jpeg_mem_src(j_decompress_ptr cinfo, byte *mem, int len)
+{
+    cinfo->src = (struct jpeg_source_mgr *)(*cinfo->mem->alloc_small)((j_common_ptr) cinfo, JPOOL_PERMANENT, sizeof(struct jpeg_source_mgr));
+    cinfo->src->init_source = jpg_null;
+    cinfo->src->fill_input_buffer = jpg_fill_input_buffer;
+    cinfo->src->skip_input_data = jpg_skip_input_data;
+    cinfo->src->resync_to_restart = jpeg_resync_to_restart;
+    cinfo->src->term_source = jpg_null;
+    cinfo->src->bytes_in_buffer = len;
+    cinfo->src->next_input_byte = mem;
+}
+
+#define DSTATE_START	200	/* after create_decompress */
+#define DSTATE_INHEADER	201	/* reading header markers, no SOS yet */
+
+/*
+==============
+LoadJPG
+==============
+*/
+void LoadJPG (char *filename, byte **pic, int *width, int *height)
+{
+	struct jpeg_decompress_struct	cinfo;
+	struct jpeg_error_mgr			jerr;
+	byte							*rawdata, *rgbadata, *scanline, *p, *q;
+	int								rawsize, i;
+
+	// Load JPEG file into memory
+	rawsize = FS_LoadFile(filename, (void **)&rawdata);
+	if (!rawdata)
+	{
+		return;	
+	}
+
+	// Knightmare- check for bad data
+	if (	rawdata[6] != 'J'
+		||	rawdata[7] != 'F'
+		||	rawdata[8] != 'I'
+		||	rawdata[9] != 'F') {
+		FS_FreeFile(rawdata);
+		return;
+	}
+
+	// Initialise libJpeg Object
+	cinfo.err = jpeg_std_error(&jerr);
+	jpeg_create_decompress(&cinfo);
+
+	// Feed JPEG memory into the libJpeg Object
+	jpeg_mem_src(&cinfo, rawdata, rawsize);
+
+	// Process JPEG header
+	jpeg_read_header(&cinfo, true); // bombs out here
+
+	// Start Decompression
+	jpeg_start_decompress(&cinfo);
+
+	// Check Color Components
+	if(cinfo.output_components != 3)
+	{
+		jpeg_destroy_decompress(&cinfo);
+		FS_FreeFile(rawdata);
+		return;
+	}
+
+	// Allocate Memory for decompressed image
+	rgbadata = malloc(cinfo.output_width * cinfo.output_height * 4);
+	if(!rgbadata)
+	{
+		jpeg_destroy_decompress(&cinfo);
+		FS_FreeFile(rawdata);
+		return;
+	}
+
+	// Pass sizes to output
+	*width = cinfo.output_width; *height = cinfo.output_height;
+
+	// Allocate Scanline buffer
+	scanline = malloc(cinfo.output_width * 3);
+	if(!scanline)
+	{
+		free(rgbadata);
+		jpeg_destroy_decompress(&cinfo);
+		FS_FreeFile(rawdata);
+		return;
+	}
+
+	// Read Scanlines, and expand from RGB to RGBA
+	q = rgbadata;
+	while(cinfo.output_scanline < cinfo.output_height)
+	{
+		p = scanline;
+		jpeg_read_scanlines(&cinfo, &scanline, 1);
+
+		for(i=0; i<cinfo.output_width; i++)
+		{
+			q[0] = p[0];
+			q[1] = p[1];
+			q[2] = p[2];
+			q[3] = 255;
+
+			p+=3; q+=4;
+		}
+	}
+
+	// Free the scanline buffer
+	free(scanline);
+
+	// Finish Decompression
+	jpeg_finish_decompress(&cinfo);
+
+	// Destroy JPEG object
+	jpeg_destroy_decompress(&cinfo);
+
+	// Return the 'rgbadata'
+	*pic = rgbadata;
+}
+
 
 /*
 =========================================================
@@ -974,7 +1127,7 @@ void GL_MipMap (byte *in, int width, int height)
 int		upload_width, upload_height;
 qboolean uploaded_paletted;
 // Fixed 256x256 texture size limitation - MrG
-qboolean GL_Upload32_hires (unsigned *data, int width, int height,  qboolean mipmap)
+qboolean GL_Upload32_hires (unsigned *data, int width, int height,  qboolean mipmap, qboolean is_normalmap)
 {	int		samples;
 	unsigned 	*scaled;
 	int		scaled_width, scaled_height;
@@ -1041,7 +1194,8 @@ qboolean GL_Upload32_hires (unsigned *data, int width, int height,  qboolean mip
         scaled=data; 
     } 
 
-	GL_LightScaleTexture (scaled, scaled_width, scaled_height, !mipmap);
+	if(!is_normalmap)
+		GL_LightScaleTexture (scaled, scaled_width, scaled_height, !mipmap);
     
 	if (mipmap) 
         gluBuild2DMipmaps (GL_TEXTURE_2D, samples, scaled_width, scaled_height, GL_RGBA, GL_UNSIGNED_BYTE, scaled); 
@@ -1093,7 +1247,7 @@ void GL_BuildPalettedTexture( unsigned char *paletted_texture, unsigned char *sc
 	}
 }
 
-qboolean GL_Upload32 (unsigned *data, int width, int height, qboolean mipmap)
+qboolean GL_Upload32 (unsigned *data, int width, int height, qboolean mipmap, qboolean is_normalmap)
 {
 	int			samples;
 	unsigned	scaled[256*256];
@@ -1202,7 +1356,8 @@ qboolean GL_Upload32 (unsigned *data, int width, int height, qboolean mipmap)
 	else
 		GL_ResampleTexture (data, width, height, scaled, scaled_width, scaled_height);
 
-	GL_LightScaleTexture (scaled, scaled_width, scaled_height, !mipmap );
+	if(!is_normalmap)
+		GL_LightScaleTexture (scaled, scaled_width, scaled_height, !mipmap );
 
 	// textures.
 	if ( qglColorTableEXT && gl_ext_palettedtexture->value && ( samples == gl_solid_format ) )
@@ -1344,9 +1499,9 @@ qboolean GL_Upload8 (byte *data, int width, int height,  qboolean mipmap, qboole
 			}
 		}
 		if(gl_texres->value)
-			return GL_Upload32_hires (trans, width, height, mipmap);
+			return GL_Upload32_hires (trans, width, height, mipmap, false);
 		else
-			return GL_Upload32 (trans, width, height, mipmap);
+			return GL_Upload32 (trans, width, height, mipmap, false);
 	}
 }
 
@@ -1424,10 +1579,10 @@ nonscrap:
 		if (bits == 8)
 			image->has_alpha = GL_Upload8 (pic, width, height, (image->type != it_pic && image->type != it_sky), image->type == it_sky );
 		else {
-			if(gl_texres->value || r_bloom->value)
-				image->has_alpha = GL_Upload32_hires ((unsigned *)pic, width, height, (image->type != it_pic && image->type != it_sky) );
+			if(gl_texres->value)
+				image->has_alpha = GL_Upload32_hires ((unsigned *)pic, width, height, (image->type != it_pic && image->type != it_sky), image->type == it_bump );
 			else
-				image->has_alpha = GL_Upload32 ((unsigned *)pic, width, height, (image->type != it_pic && image->type != it_sky) );
+				image->has_alpha = GL_Upload32 ((unsigned *)pic, width, height, (image->type != it_pic && image->type != it_sky), image->type == it_bump );
 		}
 		image->upload_width = upload_width;		// after power of 2 and scales
 		image->upload_height = upload_height;
@@ -1525,7 +1680,12 @@ image_t	*GL_FindImage (char *name, imagetype_t type)
 		image = GL_LoadPic (name, pic, width, height, type, 32);
 		goto done;
 	}
-
+	LoadJPG (va("%s.jpg", shortname), &pic, &width, &height);
+	if (pic) 
+	{
+		image = GL_LoadPic (name, pic, width, height, type, 32);
+		goto done;
+	}
 	// then comes .pcx
 	LoadPCX (va("%s.pcx", shortname), &pic, &palette, &width, &height);
 	if (pic) 
@@ -1544,8 +1704,6 @@ done:
 	if (palette)
 		free(palette);
 
-	//image->script = RS_FindScript(shortname); god only knows why this crashes everything
-
 	return image; 
 }
 
@@ -1603,6 +1761,8 @@ void GL_FreeUnusedImages (void)
 	r_bullettexture->registration_sequence = registration_sequence;
 	r_sayicontexture->registration_sequence = registration_sequence;
 	r_voltagetexture->registration_sequence = registration_sequence;
+	r_cubemap->registration_sequence = registration_sequence;
+	r_raintexture->registration_sequence = registration_sequence;
 
 	//minimap stuff - only if those textures are present, as this was a feature added later on
 	//and if crx has been updated via galaxy, clients may not have these images
