@@ -26,86 +26,6 @@ int	r_dlightframecount;
 // #define	DLIGHT_CUTOFF	64
 #define DLIGHT_CUTOFF	0
 
-/*
-=============================================================================
-
-DYNAMIC LIGHTS BLEND RENDERING
-
-=============================================================================
-*/
-
-void R_RenderDlight (dlight_t *light)
-{
-	int		i, j;
-	float	a;
-	vec3_t	v;
-	float	rad;
-
-	rad = light->intensity * 0.35;
-
-	VectorSubtract (light->origin, r_origin, v);
-#if 0
-	// FIXME?
-	if (VectorLength (v) < rad)
-	{	// view is inside the dlight
-		V_AddBlend (light->color[0], light->color[1], light->color[2], light->intensity * 0.0003, v_blend);
-		return;
-	}
-#endif
-
-	qglBegin (GL_TRIANGLE_FAN);
-	qglColor3f (light->color[0]*0.2, light->color[1]*0.2, light->color[2]*0.2);
-	for (i=0 ; i<3 ; i++)
-		v[i] = light->origin[i] - vpn[i]*rad;
-	qglVertex3fv (v);
-	qglColor3f (0,0,0);
-	for (i=16 ; i>=0 ; i--)
-	{
-		a = i/16.0 * M_PI*2;
-		for (j=0 ; j<3 ; j++)
-			v[j] = light->origin[j] + vright[j]*cos(a)*rad
-				+ vup[j]*sin(a)*rad;
-		qglVertex3fv (v);
-	}
-	qglEnd ();
-}
-
-/*
-=============
-R_RenderDlights
-=============
-*/
-void R_RenderDlights (void)
-{
-	int		i;
-	dlight_t	*l;
-
-	//if (!gl_flashblend->value)
-	//	return;
-	//took this out, because the ONLY thing this is for now are team markers
-
-	r_dlightframecount = r_framecount + 1;	// because the count hasn't
-											//  advanced yet for this frame
-	qglDepthMask (0);
-	qglDisable (GL_TEXTURE_2D);
-	qglShadeModel (GL_SMOOTH);
-	qglEnable (GL_BLEND);
-	qglBlendFunc (GL_ONE, GL_ONE);
-
-	l = r_newrefdef.dlights;
-	for (i=0 ; i<r_newrefdef.num_dlights ; i++, l++)
-	{
-		if(l->team)
-			R_RenderDlight (l);
-	}
-	qglColor3f (1,1,1);
-	qglDisable (GL_BLEND);
-	qglEnable (GL_TEXTURE_2D);
-	qglBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
-	qglDepthMask (1);
-}
-
-
 /*
 =============================================================================
 
@@ -1073,13 +993,17 @@ void R_RenderFlare (flare_t *light)
 	VectorSubtract (light->origin, r_origin, v);
 	dist = VectorLength(v) * (light->size*0.01);
 
+	//limit their size to reasonable.
+	if(dist > 10*light->size)
+		dist = 10*light->size;
+
 	qglDisable(GL_DEPTH_TEST);
 	qglEnable (GL_TEXTURE_2D);
 	GL_Bind(flaretex);
 	qglEnableClientState( GL_COLOR_ARRAY );
 	GL_TexEnv( GL_MODULATE );
 
-	VectorScale(light->color, 0.5, tmp );
+	VectorScale(light->color, light->alpha, tmp );
 	for (j=0; j<4; j++)
 	   VA_SetElem4(col_array[j], tmp[0],tmp[1],tmp[2], 1);
 
@@ -1108,13 +1032,19 @@ void R_RenderFlare (flare_t *light)
 	qglDisableClientState(GL_COLOR_ARRAY);
 
 }
-extern qboolean IsVisible(vec3_t org1,vec3_t org2);
+
 int r_numflares;
 flare_t r_flares[MAX_FLARES];
 void R_RenderFlares (void)
 {
 	flare_t	*l;
     int i;
+	qboolean visible;
+	vec3_t mins, maxs;
+	trace_t r_trace;
+
+	VectorSet(mins, 0, 0, 0);
+	VectorSet(maxs, 0, 0, 0);
 
 	if(!r_lensflare->value)
 		return;
@@ -1125,10 +1055,27 @@ void R_RenderFlares (void)
 	qglEnable (GL_BLEND);
 	qglBlendFunc   (GL_SRC_ALPHA, GL_ONE);
 
-     l = r_flares;
+    l = r_flares;
     for (i=0; i<r_numflares ; i++, l++)
 	{
-		if (IsVisible(r_origin,l->origin))
+
+		// periodically test visibility to ramp alpha
+		if(rs_realtime - l->time > 0.02){
+			
+			r_trace = CM_BoxTrace(r_origin, l->origin, mins, maxs, r_worldmodel->firstnode, MASK_SHOT);
+			visible = r_trace.fraction == 1.0;
+			
+			l->alpha += (visible ? 0.03 : -0.15);  // ramp
+			
+			if(l->alpha > 0.5)  // clamp
+				l->alpha = 0.5;
+			else if(l->alpha < 0)
+				l->alpha = 0.0;
+			
+			l->time = rs_realtime;
+		}
+
+		if (l->alpha > 0)
 		{
 			R_RenderFlare (l);
 				c_flares++;
@@ -1146,7 +1093,6 @@ void R_RenderFlares (void)
 R_ShadowLight
 ===============
 */
-//bleh, need this
 void vectoangles (vec3_t value1, vec3_t angles)
 {
 	float	forward;
