@@ -77,10 +77,13 @@ image_t		*r_beam2texture;
 image_t		*r_beam3texture;
 image_t		*r_bullettexture;
 image_t		*r_voltagetexture;
+image_t		*r_raintexture;
 image_t		*r_radarmap; // wall texture for radar texgen
 image_t		*r_around;
 
 cvar_t	*gl_normalmaps;
+cvar_t	*gl_specularmaps;
+cvar_t	*gl_cubemaps;
 cvar_t	*gl_arb_fragment_program; // jit
 
 entity_t	*currententity;
@@ -226,73 +229,7 @@ struct r_fog
 	float end;
 	float density;
 } fog;
-
-void R_AddGlowEffect (float red, float green, float blue, float radius, vec3_t origin);
-
-
-// glow definitions - originally from gl_rmain.c
-#define MAX_GLOWS 2048
-int num_glows;
-
-typedef struct glows_s
-{
-	float red;
-	float green;
-	float blue;
-	float radius;
-	vec3_t origin;
-} glows_t;
-
-glows_t glow_effects[MAX_GLOWS];
-
-// sin and cos tables from 0 to 1 in 0.0625 increments to speed up glow rendering
-// also from gl_rmisc.c and externed in gl_quake.h - i also use them for alias model glows.
-float glowcos[17] =
-{
-	1.000000,
-	0.923879,
-	0.707106,
-	0.382682,
-	-0.000002,
-	-0.382686,
-	-0.707109,
-	-0.923881,
-	-1.000000,
-	-0.923878,
-	-0.707103,
-	-0.382678,
-	0.000006,
-	0.382689,
-	0.707112,
-	0.923882,
-	1.000000,
-};
-
-
-float glowsin[17] =
-{
-	0.000000,
-	0.382684,
-	0.707107,
-	0.923880,
-	1.000000,
-	0.923879,
-	0.707105,
-	0.382680,
-	-0.000004,
-	-0.382687,
-	-0.707110,
-	-0.923882,
-	-1.000000,
-	-0.923877,
-	-0.707102,
-	-0.382677,
-	0.000008,
-};
-
-
-// this prototype was not required in my original engine
-void R_RenderGlowEffects (void);
+unsigned r_weather;  
 
 /*
 =================
@@ -341,6 +278,8 @@ void R_ReadFogScript(char config_file[128])
 	fog.end = atof(a_string);
 	strcpy( a_string, COM_Parse( &s ) );
 	fog.density = atof(a_string);
+	strcpy( a_string, COM_Parse( &s ) );
+	r_weather = atoi(a_string);
 	if ( fp != 0 )
 	{
 		fp = 0;
@@ -404,6 +343,7 @@ void R_ReadMusicScript(char config_file[128])
 	return;
 }
 #endif
+
 /*
 =================
 R_CullBox
@@ -645,7 +585,7 @@ void GL_DrawParticles( int num_particles, gparticle_t particles[], const unsigne
 	int			    oldtype;
 	int				texnum, blenddst, blendsrc;
 	float			*corner0 = corner[0];
-	vec3_t move, delta;
+	vec3_t move, delta, v;
 
 	if ( !num_particles )
 		return;
@@ -657,12 +597,15 @@ void GL_DrawParticles( int num_particles, gparticle_t particles[], const unsigne
 	for ( p = particles, i=0, oldtype=-1 ; i < num_particles ; i++,p++)
 	{
 
-		if(p->type == PARTICLE_NONE){
-				texnum = r_particletexture->texnum;
-				scale = 1;
-				*(int *)color = colortable[p->color];
-				blendsrc = GL_SRC_ALPHA;
-				blenddst = GL_ONE;
+		if(p->type == PARTICLE_NONE || p->type == PARTICLE_WEATHER){
+			if(r_weather == 1)
+				texnum = r_raintexture->texnum; //rain
+			else
+				texnum = r_particletexture->texnum; //snow
+			scale = 1;
+			*(int *)color = colortable[p->color];
+			blendsrc = GL_SRC_ALPHA;
+			blenddst = GL_ONE;
 		}
 		else {
 			texnum = p->texnum;
@@ -743,6 +686,13 @@ void GL_DrawParticles( int num_particles, gparticle_t particles[], const unsigne
 				VectorScale(up, -5*scale, pup);
 			}
 		}
+		else if(p->type == PARTICLE_WEATHER){  // keep it vertical
+			VectorCopy(r_newrefdef.viewangles, v);
+			v[0] = 0;  // keep weather particles vertical by removing pitch
+			AngleVectors(v, NULL, right, up);	
+			VectorScale(right, 3*scale, pright);
+			VectorScale(up, 3*scale, pup);
+		}
 		else {
 			VectorScale ( right, p->dist, pright );
 			VectorScale ( up, p->dist, pup );
@@ -1320,8 +1270,6 @@ void R_RenderView (refdef_t *fd)
 
 	R_BloomBlend( fd );//BLOOMS
 
-	R_RenderDlights ();
-
 // start MPO
 	// if we are doing a reflection, turn off clipping now
 	if (g_drawing_refl)
@@ -1511,7 +1459,7 @@ void R_Register( void )
 	gl_mode = Cvar_Get( "gl_mode", "6", CVAR_ARCHIVE );
 	gl_lightmap = Cvar_Get ("gl_lightmap", "0", 0);
 	gl_shadows = Cvar_Get ("gl_shadows", "2", CVAR_ARCHIVE );
-	gl_dynamic = Cvar_Get ("gl_dynamic", "1", CVAR_ARCHIVE);
+	gl_dynamic = Cvar_Get ("gl_dynamic", "0", CVAR_ARCHIVE);
 	gl_nobind = Cvar_Get ("gl_nobind", "0", 0);
 	gl_round_down = Cvar_Get ("gl_round_down", "1", 0);
 	gl_picmip = Cvar_Get ("gl_picmip", "0", 0);
@@ -1521,7 +1469,7 @@ void R_Register( void )
 	gl_clear = Cvar_Get ("gl_clear", "0", 0);
 	gl_cull = Cvar_Get ("gl_cull", "1", 0);
 	gl_polyblend = Cvar_Get ("gl_polyblend", "1", 0);
-	gl_flashblend = Cvar_Get ("gl_flashblend", "0", 0);
+	gl_flashblend = Cvar_Get ("gl_flashblend", "0", CVAR_ARCHIVE);
 	gl_playermip = Cvar_Get ("gl_playermip", "0", 0);
 #ifdef __unix__
 	gl_driver = Cvar_Get( "gl_driver", "libGL.so.1", CVAR_ARCHIVE );
@@ -1565,6 +1513,9 @@ void R_Register( void )
 	vid_ref = Cvar_Get( "vid_ref", "gl", CVAR_ARCHIVE );
 
 	gl_normalmaps = Cvar_Get("gl_normalmaps", "0", CVAR_ARCHIVE);
+	//these next two are only used when normalmaps are set to on
+	gl_specularmaps = Cvar_Get("gl_specularmaps", "1", CVAR_ARCHIVE);
+	gl_cubemaps = Cvar_Get("gl_cubemaps", "1", CVAR_ARCHIVE);
 
 	r_lensflare = Cvar_Get( "r_lensflare", "1", CVAR_ARCHIVE );
 	r_lensflare_intens = Cvar_Get ("r_lensflare_intens", "3", CVAR_ARCHIVE);
@@ -1800,13 +1751,10 @@ int R_Init( void *hinstance, void *hWnd )
 
 	if (strstr(gl_config.extensions_string, "GL_EXT_point_parameters"))
 	{
-		//if(gl_ext_pointparameters->value)
-		if (0) // Workaround for ATI driver bug.
+		if(gl_ext_pointparameters->value)
 		{
 			qglPointParameterfEXT = (void(APIENTRY*)(GLenum, GLfloat))qwglGetProcAddress("glPointParameterfEXT");
 			qglPointParameterfvEXT = (void(APIENTRY*)(GLenum, const GLfloat*))qwglGetProcAddress("glPointParameterfvEXT");
-
-
 		}
 		else
 		{
@@ -1863,6 +1811,7 @@ int R_Init( void *hinstance, void *hWnd )
 		{
 			Com_Printf ("...using GL_ARB_multitexture\n" );
 			qglMTexCoord2fSGIS = ( void * ) qwglGetProcAddress( "glMultiTexCoord2fARB" );
+			qglMTexCoord3fSGIS = ( void * ) qwglGetProcAddress( "glMultiTexCoord3fARB" );
 			qglMultiTexCoord3fvARB = (void*)qwglGetProcAddress("glMultiTexCoord3fvARB");
 			qglActiveTextureARB = ( void * ) qwglGetProcAddress( "glActiveTextureARB" );
 			qglClientActiveTextureARB = ( void * ) qwglGetProcAddress( "glClientActiveTextureARB" );
@@ -1890,6 +1839,7 @@ int R_Init( void *hinstance, void *hWnd )
 		{
 			Com_Printf ("...using GL_SGIS_multitexture\n" );
 			qglMTexCoord2fSGIS = ( void * ) qwglGetProcAddress( "glMTexCoord2fSGIS" );
+			qglMTexCoord3fSGIS = ( void * ) qwglGetProcAddress( "glMTexCoord3fSGIS" );
 			qglSelectTextureSGIS = ( void * ) qwglGetProcAddress( "glSelectTextureSGIS" );
 			GL_TEXTURE0 = GL_TEXTURE0_SGIS;
 			GL_TEXTURE1 = GL_TEXTURE1_SGIS;
@@ -1903,87 +1853,46 @@ int R_Init( void *hinstance, void *hWnd )
 	{
 		Com_Printf ("...GL_SGIS_multitexture not found\n" );
 	}
+	
 	// Vic - begin
-
 	gl_config.mtexcombine = false;
-
-
-
 	if ( strstr( gl_config.extensions_string, "GL_ARB_texture_env_combine" ) )
-
 	{
-
 		if ( gl_ext_mtexcombine->value )
-
 		{
-
 			Com_Printf( "...using GL_ARB_texture_env_combine\n" );
-
 			gl_config.mtexcombine = true;
-
 		}
-
 		else
-
 		{
-
 			Com_Printf( "...ignoring GL_ARB_texture_env_combine\n" );
-
 		}
-
 	}
-
 	else
-
 	{
-
 		Com_Printf( "...GL_ARB_texture_env_combine not found\n" );
-
 	}
-
-
-
 	if ( !gl_config.mtexcombine )
-
 	{
-
 		if ( strstr( gl_config.extensions_string, "GL_EXT_texture_env_combine" ) )
-
 		{
-
 			if ( gl_ext_mtexcombine->value )
-
 			{
-
 				Com_Printf( "...using GL_EXT_texture_env_combine\n" );
-
 				gl_config.mtexcombine = true;
-
 			}
-
 			else
-
 			{
-
 				Com_Printf( "...ignoring GL_EXT_texture_env_combine\n" );
-
 			}
-
 		}
-
 		else
-
 		{
-
 			Com_Printf( "...GL_EXT_texture_env_combine not found\n" );
-
 		}
-
 	}
-
 	// Vic - end
 
-
 	// Texture Shader support - MrG
 	if ( strstr( gl_config.extensions_string, "GL_NV_texture_shader" ) )
 	{
@@ -2321,71 +2230,3 @@ void R_DrawBeam( entity_t *e )
 	qglDepthMask( GL_TRUE );
 }
 
-// glow rendering - this was originally in gl_rmain.c
-void R_RenderGlowEffects (void)
-{
-	int i, j, k;
-	vec3_t v;
-
-	// replace this with your own fog stuff if you're using fog
-	if (map_fog)
-		qglDisable (GL_FOG);
-
-	qglDepthMask (0);
-	qglDisable (GL_TEXTURE_2D);
-	qglShadeModel (GL_SMOOTH);
-	qglEnable (GL_BLEND);
-	qglBlendFunc (GL_ONE, GL_ONE);
-
-	for (k = 0; k < num_glows; k++)
-	{
-		qglBegin (GL_TRIANGLE_FAN);
-		qglColor3f (glow_effects[k].red, glow_effects[k].green, glow_effects[k].blue);
-
-		for (i = 0; i < 3; i++)
-			v[i] = glow_effects[k].origin[i] - vpn[i] * glow_effects[k].radius;
-
-		qglVertex3fv (v);
-		qglColor3f (0,0,0);
-
-		for (i = 16; i >= 0; i--)
-		{
-			for (j = 0; j < 3; j++)
-				v[j] = glow_effects[k].origin[j] + vright[j] * glowcos[i] *
-					glow_effects[k].radius + vup[j] * glowsin[i] * glow_effects[k].radius;
-
-			qglVertex3fv (v);
-		}
-
-		qglEnd ();
-	}
-
-	qglColor3f (1,1,1);
-	qglDisable (GL_BLEND);
-	qglEnable (GL_TEXTURE_2D);
-	qglBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
-	qglDepthMask (1);
-
-	// replace this with your own fog stuff if you're using fog
-	if (map_fog)
-		qglEnable (GL_FOG);
-}
-
-
-void R_AddGlowEffect (float red, float green, float blue, float radius, vec3_t origin)
-{
-	glow_effects[num_glows].red = red;
-	glow_effects[num_glows].green = green;
-	glow_effects[num_glows].blue = blue;
-
-	glow_effects[num_glows].radius = radius;
-
-	glow_effects[num_glows].origin[0] = origin[0];
-	glow_effects[num_glows].origin[1] = origin[1];
-	glow_effects[num_glows].origin[2] = origin[2];
-
-	num_glows++;
-}
-
-
-
