@@ -30,11 +30,58 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <jpeglib.h>
 #endif
 
-
 image_t *r_flare;
 image_t *r_cubemap;
 
 #define CUBEMAP_MAXSIZE 32
+void MakeSpecularAttenuationMap (byte *pixels)
+{
+	int x, y;
+	int LRADIUS = CUBEMAP_MAXSIZE / 2;
+
+	for (y = 0; y < CUBEMAP_MAXSIZE; y++)
+	{
+		for (x = 0; x < CUBEMAP_MAXSIZE; x++)
+		{
+			// find x and y as a -LRADIUS to LRADIUS scale
+			int TheRX = x - LRADIUS;
+			int TheRY = y - LRADIUS;
+			float TheXResult;
+			float TheYResult;
+			float TheFinalResult;
+			unsigned char OutResult;
+
+			// divide X by LRADIUS and square it
+			TheXResult = ((float) TheRX / (float) LRADIUS);
+			TheXResult *= TheXResult;
+
+			// divide Y by LRADIUS and square it
+			TheYResult = ((float) TheRY / (float) LRADIUS);
+			TheYResult *= TheYResult;
+
+			// add the 2
+			TheFinalResult = TheXResult + TheYResult;
+
+			// multiply by 255 for a byte intensity range
+			TheFinalResult = TheFinalResult * 255;
+
+			// clamp 0 to 255
+			if (TheFinalResult < 0) TheFinalResult = 0;
+			if (TheFinalResult > 255) TheFinalResult = 255;
+
+			// store in an unsigned char now - we want the negative of what is generated above
+			OutResult = 255 - (unsigned char) TheFinalResult;
+
+			// write to output
+			pixels[0] = OutResult;
+			pixels[1] = OutResult;
+			pixels[2] = OutResult;
+			pixels[3] = 255;
+
+			pixels += 4;
+		}
+	}
+}
 
 static void getCubeVector (int i, int cubesize, int x, int y, float *vector)
 {
@@ -65,30 +112,24 @@ static void getCubeVector (int i, int cubesize, int x, int y, float *vector)
 
 void R_InitCubemapTextures (void)
 {
-	// this texture doesn't need to be huge. I've seen examples where it goes up to 128 or higher, but 32
-	// is perfectly adequate. Who am I to argue with Mr. Kilgard?
 	float vector[3];
 	int i, x, y;
-	GLubyte pixels[CUBEMAP_MAXSIZE * CUBEMAP_MAXSIZE * 4];
-
-	// set up a dummy for it to get a valid image_t filled in.  we'll be deleting and recreating the texture data
-	// using glTexImage2D when we actually set up each individual one.  we generate it as a wall texture to ensure that
-	// we get texnums generated for the backup textures as well
-	r_cubemap = GL_LoadPic ("***cubemap***", (byte *) pixels, CUBEMAP_MAXSIZE, CUBEMAP_MAXSIZE, it_pic, 32);
+	byte pixels[CUBEMAP_MAXSIZE * CUBEMAP_MAXSIZE * 4];
 
 	// switch the texture state
 	qglDisable (GL_TEXTURE_2D);
-	qglEnable (GL_TEXTURE_CUBE_MAP_EXT);
+	qglEnable (GL_TEXTURE_CUBE_MAP_ARB);
 
 	// bind to the regular texture number
-	qglBindTexture (GL_TEXTURE_CUBE_MAP_EXT, r_cubemap->texnum);
+	qglBindTexture (GL_TEXTURE_CUBE_MAP_ARB, r_cubemap->texnum);
+	qglGetError(); //binding this 2d texture initially causes a harmless error
 
 	// set up the texture parameters - did a clamp on R as well...
-	qglTexParameteri (GL_TEXTURE_CUBE_MAP_EXT, GL_TEXTURE_WRAP_S, GL_CLAMP_TO_EDGE);
-	qglTexParameteri (GL_TEXTURE_CUBE_MAP_EXT, GL_TEXTURE_WRAP_T, GL_CLAMP_TO_EDGE);
-	qglTexParameteri (GL_TEXTURE_CUBE_MAP_EXT, GL_TEXTURE_WRAP_R, GL_CLAMP_TO_EDGE);
-	qglTexParameteri (GL_TEXTURE_CUBE_MAP_EXT, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
-	qglTexParameteri (GL_TEXTURE_CUBE_MAP_EXT, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
+	qglTexParameteri (GL_TEXTURE_CUBE_MAP_ARB, GL_TEXTURE_WRAP_S, GL_CLAMP_TO_EDGE);
+	qglTexParameteri (GL_TEXTURE_CUBE_MAP_ARB, GL_TEXTURE_WRAP_T, GL_CLAMP_TO_EDGE);
+	qglTexParameteri (GL_TEXTURE_CUBE_MAP_ARB, GL_TEXTURE_WRAP_R, GL_CLAMP_TO_EDGE);
+	qglTexParameteri (GL_TEXTURE_CUBE_MAP_ARB, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
+	qglTexParameteri (GL_TEXTURE_CUBE_MAP_ARB, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
 
 	for (i = 0; i < 6; i++)
 	{
@@ -105,14 +146,16 @@ void R_InitCubemapTextures (void)
 		}
 
 		// cube map me baybeee
-		qglTexImage2D (GL_TEXTURE_CUBE_MAP_POSITIVE_X_EXT + i, 0, GL_RGBA, CUBEMAP_MAXSIZE, CUBEMAP_MAXSIZE, 0, GL_RGBA, GL_UNSIGNED_BYTE, pixels);
+		qglTexImage2D (GL_TEXTURE_CUBE_MAP_POSITIVE_X_ARB + i, 0, GL_RGBA, CUBEMAP_MAXSIZE, CUBEMAP_MAXSIZE, 0, GL_RGBA, GL_UNSIGNED_BYTE, pixels);
 	}
+	MakeSpecularAttenuationMap (pixels);
+	qglTexImage2D (GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_ARB, 0, GL_RGBA, CUBEMAP_MAXSIZE, CUBEMAP_MAXSIZE, 0, GL_RGBA, GL_UNSIGNED_BYTE, pixels);
 
 	// done - restore the texture state
-	qglDisable (GL_TEXTURE_CUBE_MAP_EXT);
+	qglDisable (GL_TEXTURE_CUBE_MAP_ARB);
 	qglEnable (GL_TEXTURE_2D);
 }
-#undef CUBEMAP_MAXSIZE
+
 /*
 ==================
 R_InitParticleTexture
@@ -142,6 +185,7 @@ void R_InitParticleTexture (void)
 {
 	int		x,y;
 	byte	data[16][16][4];
+	byte pixels[CUBEMAP_MAXSIZE * CUBEMAP_MAXSIZE * 4];
 	char flares[MAX_QPATH];
 	//
 	// particle texture
@@ -182,11 +226,12 @@ void R_InitParticleTexture (void)
 	r_shottexture = R_RegisterParticlePic("dflash");
 	r_sayicontexture = R_RegisterParticlePic("sayicon");
 	r_flaretexture = R_RegisterParticlePic("flare");
-	r_beamtexture = R_RegisterGfxPic("greenlightning");
+	r_beamtexture = R_RegisterGfxPic("glightning");
 	r_beam2texture = R_RegisterGfxPic("greenline");
 	r_beam3texture = R_RegisterGfxPic("electrics3d");
 	r_bullettexture = R_RegisterParticlePic("bullethole");
 	r_voltagetexture = R_RegisterParticlePic("voltage");
+	r_raintexture = R_RegisterParticlePic("beam");
 	r_radarmap = GL_FindImage("gfx/radar/radarmap",it_pic);
 	r_around = GL_FindImage("gfx/radar/around",it_pic);
 
@@ -210,7 +255,10 @@ void R_InitParticleTexture (void)
 	}
 	r_notexture = GL_LoadPic ("***r_notexture***", (byte *)data, 16, 16, it_wall, 32);
 
-	//R_InitCubemapTextures (); //for future use
+	r_cubemap = GL_LoadPic ("***cubemap***", (byte *) pixels, CUBEMAP_MAXSIZE, CUBEMAP_MAXSIZE, it_pic, 32);
+
+	if(gl_cubemaps->value)
+		R_InitCubemapTextures (); 
 
 	Com_sprintf (flares, sizeof(flares), "gfx/flares/flare0.tga");
 	r_flare = GL_FindImage(flares, it_pic);
