@@ -45,6 +45,7 @@ extern void R_ReadMusicScript(char config_file[128]);
 #endif
 
 char map_music[128];
+extern unsigned r_weather;
 
 char		map_entitystring[MAX_MAP_ENTSTRING];
 int			numentitychars;
@@ -420,12 +421,12 @@ model_t *Mod_ForName (char *name, qboolean crash)
 	switch (LittleLong(*(unsigned *)buf))
 	{
 	case IDALIASHEADER:
-		loadmodel->extradata = Hunk_Begin (0x200000);
+		loadmodel->extradata = Hunk_Begin (0x300000);
 		Mod_LoadAliasModel (mod, buf);
 		break;
 		
 	case IDBSPHEADER:
-		loadmodel->extradata = Hunk_Begin (0x1000000);
+		loadmodel->extradata = Hunk_Begin (0x1500000);
 		Mod_LoadBrushModel (mod, buf);
 		break;
 
@@ -614,6 +615,7 @@ void Mod_LoadTexinfo (lump_t *l)
 	mtexinfo_t *out, *step;
 	int 	i, j, count;
 	char	name[MAX_QPATH];
+	char	sv_name[MAX_QPATH];
 	int		next;
 
 	in = (void *)(mod_base + l->fileofs);
@@ -645,6 +647,29 @@ void Mod_LoadTexinfo (lump_t *l)
 		if (out->image->script)
 			RS_ReadyScript(out->image->script);
 
+		//check for normal and specular maps
+		strcpy(sv_name, name);
+		if( ( strlen( name ) + 8 ) <= MAX_QPATH )
+		{
+			strcat( name, "_nm.tga" );
+			out->normalMap = GL_FindImage( name, it_bump );
+			if( out->normalMap == NULL ) 
+				out->normalMap = out->image; 
+		
+		}
+		else
+			out->normalMap = out->image; 
+
+		if( ( strlen( sv_name ) + 8 ) <= MAX_QPATH )
+		{
+			strcat( sv_name, "_sm.tga" );
+			out->specularMap = GL_FindImage( sv_name, it_bump );
+			if( out->specularMap == NULL ) 
+				out->specularMap = out->image; 
+		
+		}
+		else
+			out->specularMap = out->image; 
 	}
 
 	// count animation frames
@@ -1198,7 +1223,7 @@ void Mod_LoadBrushModel (model_t *mod, void *buffer)
 // swap all the lumps
 	mod_base = (byte *)header;
 
-	for (i=0 ; i<sizeof(dheader_t)/4 ; i++)
+	for (i=0 ; i<sizeof(dheader_t)/sizeof(int) ; i++)
 		((int *)header)[i] = LittleLong ( ((int *)header)[i]);
 
 // load into heap
@@ -1301,6 +1326,35 @@ void Mod_AliasCalculateVertexNormals ( int numtris, dtriangle_t *tris, int numxy
 		}
 	}
 }
+/*
+R_LoadMd2VertexArrays
+*/
+extern 
+void R_LoadMd2VertexArrays(model_t *md2model){
+
+	dmdl_t *md2;
+	daliasframe_t *md2frame;
+	dtrivertx_t	*md2v;
+	int i;
+
+	if(md2model->num_frames > 1)
+		return;
+
+	md2 = (dmdl_t *)md2model->extradata;
+	
+	md2frame = (daliasframe_t *)((byte *)md2 + md2->ofs_frames);
+
+	if(md2->num_xyz > MAX_VERTS)
+		return;
+
+	for(i = 0, md2v = md2frame->verts; i < md2->num_xyz; i++, md2v++){  // reconstruct the verts
+		VectorSet(md2model->r_mesh_verts[i],
+					md2v->v[0] * md2frame->scale[0] + md2frame->translate[0],
+					md2v->v[1] * md2frame->scale[1] + md2frame->translate[1],
+					md2v->v[2] * md2frame->scale[2] + md2frame->translate[2]);
+	}
+	
+}
 
 /*
 =================
@@ -1327,7 +1381,7 @@ void Mod_LoadAliasModel (model_t *mod, void *buffer)
 	pheader = Hunk_Alloc (LittleLong(pinmodel->ofs_end));
 	
 	// byte swap the header fields and sanity check
-	for (i=0 ; i<sizeof(dmdl_t)/4 ; i++)
+	for (i=0 ; i<sizeof(dmdl_t)/sizeof(int) ; i++)
 		((int *)pheader)[i] = LittleLong (((int *)buffer)[i]);
 
 	if (pheader->skinheight > MAX_LBM_HEIGHT)
@@ -1399,6 +1453,7 @@ void Mod_LoadAliasModel (model_t *mod, void *buffer)
 	}
 
 	mod->type = mod_alias;
+	mod->num_frames = pheader->num_frames;
 
 	//
 	// load the glcmds
@@ -1436,6 +1491,8 @@ void Mod_LoadAliasModel (model_t *mod, void *buffer)
 	mod->maxs[0] = 32;
 	mod->maxs[1] = 32;
 	mod->maxs[2] = 32;
+
+	R_LoadMd2VertexArrays(mod);
 }
 
 //=============================================================================
@@ -1470,6 +1527,8 @@ void R_BeginRegistration (char *model)
 	registration_sequence++;
 	r_oldviewcluster = -1;		// force markleafs
 
+	r_weather = 0; //default is 0
+
 	//check for fog file. (gamedir first) 
 	Com_sprintf(fullname, sizeof(fullname), "%s/maps/scripts/%s.fog", FS_Gamedir(), model);
 	i = 0;
@@ -1571,7 +1630,7 @@ struct model_s *R_RegisterModel (char *name)
 	model_t	*mod;
 	int		i;
 	dmdl_t		*pheader;
-
+	
 	mod = Mod_ForName (name, false);
 	if (mod)
 	{
@@ -1591,6 +1650,7 @@ struct model_s *R_RegisterModel (char *name)
 		{
 			for (i=0 ; i<mod->numtexinfo ; i++) {
 				mod->texinfo[i].image->registration_sequence = registration_sequence;
+				mod->texinfo[i].normalMap->registration_sequence = registration_sequence;
 			}
 		}
 	}
