@@ -27,6 +27,8 @@ static vec3_t	modelorg;		// relative to viewpoint
 
 msurface_t	*r_alpha_surfaces;
 msurface_t	*r_special_surfaces;
+msurface_t *r_normalsurfaces;
+msurface_t *r_specularsurfaces;
 
 #define DYNAMIC_LIGHT_WIDTH  128
 #define DYNAMIC_LIGHT_HEIGHT 128
@@ -359,6 +361,11 @@ void R_RenderBrushPoly (msurface_t *fa)
 		GL_TexEnv( GL_REPLACE );
 	}
 
+	fa->normalchain = r_normalsurfaces;
+	r_normalsurfaces = fa;
+	fa->specularchain = r_specularsurfaces;
+	r_specularsurfaces = fa;
+
 	if (SurfaceIsAlphaBlended(fa))
 		qglEnable( GL_ALPHA_TEST );
 
@@ -625,7 +632,12 @@ static void GL_RenderLightmappedPoly( msurface_t *surf )
 	image_t *image = R_TextureAnimation( surf->texinfo );
 	qboolean is_dynamic = false;
 	unsigned lmtex = surf->lightmaptexturenum;
-
+	
+	surf->normalchain = r_normalsurfaces;
+	r_normalsurfaces = surf;
+	surf->specularchain = r_specularsurfaces;
+	r_specularsurfaces = surf;
+	
 	for ( map = 0; map < MAXLIGHTMAPS && surf->styles[map] != 255; map++ )
 	{
 		if ( r_newrefdef.lightstyles[surf->styles[map]].white != surf->cached_light[map] )
@@ -697,6 +709,210 @@ dynamic:
 		qglDisable( GL_ALPHA_TEST);
 }
 
+//This next section deals with bumpmapped surfaces.  Much of this was gathered from Mike Hiney
+//and "Paul's Projects" tutorials.
+static void R_InitNormalSurfaces (void)
+{
+	dlight_t	*dl;
+	int			lnum;
+	vec3_t		lightAdd, angle;
+	float		add;
+
+	qglActiveTextureARB (GL_TEXTURE0);
+	qglDisable (GL_TEXTURE_2D);
+	qglEnable (GL_TEXTURE_CUBE_MAP_ARB);
+
+	qglBindTexture (GL_TEXTURE_CUBE_MAP_ARB, r_cubemap->texnum);
+	qglMatrixMode (GL_TEXTURE);
+	qglLoadIdentity ();
+
+	// rotate around Y to bring blue/pink to the front
+	qglRotatef (145, 0, 1, 0);
+
+	// now reposition so that the bright spot is center screen
+	qglRotatef (-45, 1, 0, 0);
+	qglRotatef (-45, 0, 0, 1);
+
+	// rotate by viewangles  
+	qglRotatef (-r_newrefdef.viewangles[2], 1, 0, 0);
+	qglRotatef (-r_newrefdef.viewangles[0], 0, 1, 0);
+	qglRotatef (-r_newrefdef.viewangles[1], 0, 0, 1);
+
+	//now rotate according to dynamic lights
+	VectorClear(lightAdd);
+	dl = r_newrefdef.dlights;
+	for (lnum=0; lnum<r_newrefdef.num_dlights; lnum++, dl++)
+	{
+
+		VectorSubtract (r_newrefdef.vieworg, dl->origin, angle);
+		add = sqrt(dl->intensity - VectorLength(angle));
+		VectorNormalize(angle);
+		if (add > 0)
+		{
+			VectorScale(angle, add, angle);
+			VectorAdd (lightAdd, angle, lightAdd);
+		}
+	}
+	qglRotatef (-lightAdd[2], 1, 0, 0);
+	qglRotatef (-lightAdd[0], 0, 1, 0);
+	qglRotatef (-lightAdd[1], 0, 0, 1);
+
+	// the next 2 statements will move the cmstr calculations into hardware so that we don;t
+	// have to evaluate them once per vert...
+
+	// translate after rotation
+	qglTranslatef (r_newrefdef.vieworg[0], r_newrefdef.vieworg[1], r_newrefdef.vieworg[2]);
+
+	// now flip everything by -1 again to mimic the software calculation
+	// we won't bother batching this part up...
+	qglScalef (-1, -1, -1);
+
+	qglMatrixMode (GL_MODELVIEW);
+
+	// basic replace texenv
+	qglTexEnvi (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
+}
+
+static void R_DrawNormalSurfaces (void)
+{
+	msurface_t *surf = r_normalsurfaces;
+	int		i;
+	float	*v;
+	glpoly_t *p;
+
+	// nothing to draw!
+	if (!surf)
+		return;
+
+	if (!gl_normalmaps->value)
+		return;
+
+	R_InitNormalSurfaces();
+
+	qglActiveTextureARB (GL_TEXTURE1);
+	qglEnable (GL_TEXTURE_2D);
+
+	qglTexEnvi (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_COMBINE);
+	qglTexEnvi (GL_TEXTURE_ENV, GL_COMBINE_RGB_ARB, GL_DOT3_RGB);
+	qglTexEnvi (GL_TEXTURE_ENV, GL_SOURCE0_RGB_ARB, GL_PREVIOUS_ARB);
+	qglTexEnvi (GL_TEXTURE_ENV, GL_SOURCE1_RGB_ARB, GL_TEXTURE);
+	qglTexEnvi (GL_TEXTURE_ENV, GL_OPERAND0_RGB_ARB, GL_SRC_COLOR);
+	qglTexEnvi (GL_TEXTURE_ENV, GL_OPERAND1_RGB_ARB, GL_SRC_COLOR);
+
+	qglEnable (GL_BLEND); 
+
+	// set the correct blending mode for normal maps 
+	qglBlendFunc (GL_ZERO, GL_SRC_COLOR); 
+	
+	for (; surf; surf = surf->normalchain)
+	{
+		if (SurfaceIsAlphaBlended(surf))
+			continue;
+		if(strcmp(surf->texinfo->normalMap->name, surf->texinfo->image->name))
+			qglBindTexture (GL_TEXTURE_2D, surf->texinfo->normalMap->texnum);
+		else
+			continue;
+
+		for (p = surf->polys; p; p = p->chain)
+		{
+			qglBegin (GL_POLYGON);
+
+			for (v = p->verts[0], i = 0 ; i < p->numverts; i++, v += VERTEXSIZE)
+			{		
+				qglMTexCoord3fSGIS(GL_TEXTURE0, v[0], v[1], v[2]);
+				qglMTexCoord2fSGIS(GL_TEXTURE1, v[3], v[4]);
+				qglVertex3fv (v);
+			}
+
+			qglEnd ();
+		}
+	}
+
+	//kill TMU1
+	qglActiveTextureARB (GL_TEXTURE1);
+	qglTexEnvi (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
+	qglDisable (GL_TEXTURE_2D);
+
+	//kill TMU0
+	qglActiveTextureARB (GL_TEXTURE0);
+	qglMatrixMode (GL_TEXTURE);
+	qglLoadIdentity ();
+	qglMatrixMode (GL_MODELVIEW);
+	qglDisable (GL_TEXTURE_CUBE_MAP_ARB);
+	qglEnable (GL_TEXTURE_2D);
+
+	// restore original blend
+	qglTexEnvf (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
+	qglBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+	qglDisable (GL_BLEND);
+}
+static void R_DrawSpecularSurfaces (void)
+{
+	msurface_t *surf = r_specularsurfaces;
+	int		i;
+	float	*v;
+	glpoly_t *p;
+
+	// nothing to draw!
+	if (!surf)
+		return;
+
+	if (!gl_normalmaps->value || !gl_specularmaps->value)
+		return;
+
+	R_InitNormalSurfaces();
+
+	qglActiveTextureARB (GL_TEXTURE1);
+	qglEnable (GL_TEXTURE_2D);
+	qglTexEnvi (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
+
+	qglDepthMask (GL_FALSE); 
+	qglEnable (GL_BLEND); 
+	qglBlendFunc (GL_ONE, GL_ONE);
+	
+	for (; surf; surf = surf->specularchain)
+	{
+		if (SurfaceIsAlphaBlended(surf))
+			continue;
+		if(strcmp(surf->texinfo->specularMap->name, surf->texinfo->image->name))
+			qglBindTexture (GL_TEXTURE_2D, surf->texinfo->specularMap->texnum);
+		else
+			continue;
+
+		for (p = surf->polys; p; p = p->chain)
+		{
+			qglBegin (GL_POLYGON);
+
+			for (v = p->verts[0], i = 0 ; i < p->numverts; i++, v += VERTEXSIZE)
+			{			
+				qglMTexCoord3fSGIS(GL_TEXTURE0, v[0], v[1], v[2]);
+				qglMTexCoord2fSGIS(GL_TEXTURE1, v[3], v[4]);
+				qglVertex3fv (v);
+			}
+
+			qglEnd ();
+		}
+	}
+
+		//kill TMU1
+	qglActiveTextureARB (GL_TEXTURE1);
+	qglTexEnvi (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
+	qglDisable (GL_TEXTURE_2D);
+
+	//kill TMU0
+	qglActiveTextureARB (GL_TEXTURE0);
+	qglMatrixMode (GL_TEXTURE);
+	qglLoadIdentity ();
+	qglMatrixMode (GL_MODELVIEW);
+	qglDisable (GL_TEXTURE_CUBE_MAP_ARB);
+	qglEnable (GL_TEXTURE_2D);
+
+	// restore original blend
+	qglDepthMask (GL_TRUE);
+	qglTexEnvf (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
+	qglBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+	qglDisable (GL_BLEND);
+}
 /*
 =================
 R_DrawInlineBModel
@@ -718,6 +934,9 @@ void R_DrawInlineBModel (entity_t *e)
 		GL_TexEnv( GL_MODULATE );
 	}
 
+	r_normalsurfaces = NULL;
+	r_specularsurfaces = NULL;
+
 	//
 	// draw texture
 	//
@@ -755,8 +974,15 @@ void R_DrawInlineBModel (entity_t *e)
 
 	if ( !(currententity->flags & RF_TRANSLUCENT) )
 	{
-		if ( !qglMTexCoord2fSGIS )
+		if ( !qglMTexCoord2fSGIS ) {
 			R_BlendLightmaps ();
+
+			GL_EnableMultitexture (true);
+			R_DrawNormalSurfaces ();
+			R_DrawSpecularSurfaces ();
+			GL_EnableMultitexture (false);
+		}
+
 	}
 	else
 	{
@@ -1083,6 +1309,9 @@ void R_DrawWorld (void)
 	qglColor3f (1,1,1);
 	memset (gl_lms.lightmap_surfaces, 0, sizeof(gl_lms.lightmap_surfaces));
 
+	r_normalsurfaces = NULL;
+	r_specularsurfaces = NULL;
+
 	R_ClearSkyBox ();
 
 	if ( qglMTexCoord2fSGIS )
@@ -1145,6 +1374,11 @@ void R_DrawWorld (void)
 	DrawTextureChains ();
 	R_BlendLightmaps ();
 
+	GL_EnableMultitexture( true );
+	R_DrawNormalSurfaces ();
+	R_DrawSpecularSurfaces ();
+	GL_EnableMultitexture( false );	
+
 	R_DrawSkyBox ();
 
 	R_DrawTriangleOutlines ();
@@ -1389,6 +1623,14 @@ void GL_BuildPolygonFromSurface(msurface_t *fa)
 		poly->verts[i][5] = s;
 		poly->verts[i][6] = t;
 
+		s = DotProduct (vec, fa->texinfo->vecs[0]) + fa->texinfo->vecs[0][3];
+		s /= 128;
+
+		t = DotProduct (vec, fa->texinfo->vecs[1]) + fa->texinfo->vecs[1][3];
+		t /= 128;
+
+		poly->verts[i][7] = s;
+		poly->verts[i][8] = t;
 	}
 }
 
