@@ -381,6 +381,8 @@ void HandleEvents(void)
 			else if (event.xbutton.button == 5) Key_Event(K_MWHEELDOWN, event.type == ButtonPress, Sys_Milliseconds());
 			else if (event.xbutton.button == 6) Key_Event(K_MOUSE4, event.type == ButtonPress, Sys_Milliseconds());
 			else if (event.xbutton.button == 7) Key_Event(K_MOUSE5, event.type == ButtonPress, Sys_Milliseconds());
+			else if (event.xbutton.button == 8) Key_Event(K_MOUSE6, event.type == ButtonPress, Sys_Milliseconds());
+			else if (event.xbutton.button == 9) Key_Event(K_MOUSE7, event.type == ButtonPress, Sys_Milliseconds());
 			break;
 			
 		case ButtonRelease:
@@ -396,6 +398,8 @@ void HandleEvents(void)
 			else if (event.xbutton.button == 5) Key_Event(K_MWHEELDOWN, event.type == ButtonPress, Sys_Milliseconds());
 			else if (event.xbutton.button == 6) Key_Event(K_MOUSE4, event.type == ButtonPress, Sys_Milliseconds());
 			else if (event.xbutton.button == 7) Key_Event(K_MOUSE5, event.type == ButtonPress, Sys_Milliseconds());
+			else if (event.xbutton.button == 8) Key_Event(K_MOUSE6, event.type == ButtonPress, Sys_Milliseconds());
+			else if (event.xbutton.button == 9) Key_Event(K_MOUSE7, event.type == ButtonPress, Sys_Milliseconds());
 			break;
 
 		case CreateNotify :
@@ -429,7 +433,7 @@ static void signal_handler(int sig)
 {
 	printf("Received signal %d, exiting...\n", sig);
 	GLimp_Shutdown();
-	_exit(0);
+	exit(0);
 }
 
 static void InitSig(void)
@@ -659,7 +663,6 @@ int GLimp_SetMode( int *pwidth, int *pheight, int mode, qboolean fullscreen )
 */
 void GLimp_Shutdown( void )
 {
-
 	uninstall_grabs();
 	mouse_active = false;
 	dgamouse = false;
@@ -671,6 +674,7 @@ void GLimp_Shutdown( void )
 			XDestroyWindow(dpy, win);
 		if (vidmode_active)
 			XF86VidModeSwitchToMode(dpy, scrnum, vidmodes[0]);
+		XUngrabKeyboard(dpy, CurrentTime);
 		XCloseDisplay(dpy);
 	}
 	ctx = NULL;
