@@ -44,10 +44,10 @@ glwstate_t glw_state;
 
 extern cvar_t *vid_fullscreen;
 extern cvar_t *vid_ref;
+extern cvar_t *vid_displayfrequency;
 
 qboolean have_stencil = false; // Stencil shadows - MrG
 
-
 static qboolean VerifyDriver( void )
 {
 	char buffer[1024];
@@ -214,6 +214,13 @@ rserr_t GLimp_SetMode( int *pwidth, int *pheight, int mode, qboolean fullscreen
 			ReleaseDC( 0, hdc );
 		}
 
+		if ( vid_displayfrequency->integer > 0 )
+		{
+			dm.dmFields |= DM_DISPLAYFREQUENCY;
+			dm.dmDisplayFrequency = vid_displayfrequency->integer;
+			Com_Printf ( "...using display frequency %i\n", dm.dmDisplayFrequency );
+		}
+
 		Com_Printf ("...calling CDS: " );
 		if ( ChangeDisplaySettings( &dm, CDS_FULLSCREEN ) == DISP_CHANGE_SUCCESSFUL )
 		{
@@ -248,6 +255,13 @@ rserr_t GLimp_SetMode( int *pwidth, int *pheight, int mode, qboolean fullscreen
 				dm.dmFields |= DM_BITSPERPEL;
 			}
 
+			if ( vid_displayfrequency->integer > 0 )
+			{
+				dm.dmFields |= DM_DISPLAYFREQUENCY;
+				dm.dmDisplayFrequency = vid_displayfrequency->integer;
+				Com_Printf ( "...using display frequency %i\n", dm.dmDisplayFrequency );
+			}
+
 			/*
 			** our first CDS failed, so maybe we're running on some weird dual monitor
 			** system
@@ -787,7 +801,7 @@ qboolean GLimp_InitGL (void)
 	qglEnableClientState (GL_VERTEX_ARRAY);
 	qglEnableClientState (GL_TEXTURE_COORD_ARRAY);
 
-	qglTexCoordPointer (2, GL_FLOAT, sizeof(tex_array[0]), tex_array[0]);
+	qglTexCoordPointer (2, GL_FLOAT, sizeof(tex_array[0]), tex_array[0]); //probably remove from here
 	qglVertexPointer (3, GL_FLOAT, sizeof(vert_array[0]), vert_array[0]);
 	qglColorPointer (4, GL_FLOAT, sizeof(col_array[0]), col_array[0]);
 
